/*
 *
 * Copyright (c) 2000 - 2012 Samsung Electronics Co., Ltd All Rights Reserved
 * This file is part of drm-service
 * Written by Hakjoo Ko <hakjoo.ko@samsung.com>
 * 
 * PROPRIETARY/CONFIDENTIAL
 *
 * This software is the confidential and proprietary information of
 * SAMSUNG ELECTRONICS ("Confidential Information"). You shall not 
 * disclose such Confidential Information and shall use it only in 
 * accordance with the terms of the license agreement you entered 
 * into with SAMSUNG ELECTRONICS.
 * SAMSUNG make no representations or warranties about the suitability
 * of the software, either express or implied, including but not limited
 * to the implied warranties of merchantability, fitness for a particular 
 * purpose, or non-infringement. SAMSUNG shall not be liable for any 
 * damages suffered by licensee as a result of using, modifying or 
 * distributing this software or its derivatives.
 *
 */

#ifndef __DRM_PR_MTP_TYPES_H__
#define __DRM_PR_MTP_TYPES_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <stddef.h>

#define PR_MAX_LENGTH_VENDOR_EXTENSION_DESC 256

#define PR_MTP_S_BASECODE						(0xE000)
#define PR_MTP_E_BASECODE						(0xE000)
#define PR_MTP_E_PK_BASECODE					(0xF000)

/* PlayReady Handle for MTP operation */
typedef void *DRM_PLAYREADY_MTP_HANDLE;

typedef struct {
	/* DRM_APP_CONTEXT sepcific Data */
	void *pAppContext;

	/* DRM PlayReady Revocation Buffer */
	unsigned char *RevocationBuffer;

} DRM_PR_MTP_HANDLE;

#define PR_MTP_SUCCESS							(0x00000000L)

#define PR_MTP_S_FALSE							(0x00000001L)

#define PR_MTP_S_MORE_DATA						(0x00000002L)

#define PR_MTP_E_OUTOFMEMORY					(0x10000002L)

#define PR_MTP_E_NOTIMPL						(0x10004001L)

#define PR_MTP_E_FAIL							(0x10004005L)

#define PR_MTP_E_WIN32_FILE_NOT_FOUND			(0x10070002L)

#define PR_MTP_E_WIN32_NO_MORE_FILES			(0x10070012L)

#define PR_MTP_E_INVALIDARG						(0x10070057L)

#define PR_MTP_E_BUFFERTOOSMALL					(0x1007007AL)

#define PR_MTP_E_NOMORE							(0x10070103L)

#define PR_MTP_E_ARITHMETIC_OVERFLOW			(0x10070216L)

#define PR_MTP_E_INVALID_COMMAND_LINE			(0x10070667L)

#define PR_MTP_E_FILENOTFOUND					(0x10030002L)

#define PR_MTP_E_FILEOPEN						(0x1003006EL)

#define PR_MTP_E_PARAMETERS_MISMATCHED			(0xE00D272FL)

#define PR_MTP_E_FAILED_TO_STORE_LICENSE		(0xE00D2712L)

#define PR_MTP_E_NOT_ALL_STORED					(0xE00D275FL)

#define PR_MTP_E_VERIFICATION_FAILURE			(0x10040E80L)

#define PR_MTP_E_RSA_SIGNATURE_ERROR			(0x10040E82L)

#define PR_MTP_E_BAD_RSA_EXPONENT				(0x10040E86L)

#define PR_MTP_E_P256_CONVERSION_FAILURE		(0x10040E87L)

#define PR_MTP_E_P256_PKCRYPTO_FAILURE			(0x10040E88L)

#define PR_MTP_E_P256_PLAINTEXT_MAPPING_FAILURE	(0x10040E89L)

#define PR_MTP_E_P256_INVALID_SIGNATURE			(0x10040E8AL)

#define PR_MTP_E_P256_ECDSA_VERIFICATION_ERROR	(0x10040E8BL)

#define PR_MTP_E_P256_ECDSA_SIGNING_ERROR		(0x10040E8CL)

#define PR_MTP_E_P256_HMAC_KEYGEN_FAILURE		(0x10040E8DL)

#define PR_MTP_E_CH_BASECODE					(0x10041100L)

#define PR_MTP_E_CH_VERSION_MISSING				(0x10041103L)

#define PR_MTP_E_CH_KID_MISSING					(0x10041104L)

#define PR_MTP_E_CH_LAINFO_MISSING				(0x10041105L)

#define PR_MTP_E_CH_CHECKSUM_MISSING			(0x10041106L)

#define PR_MTP_E_CH_ATTR_MISSING				(0x10041107L)

#define PR_MTP_E_CH_INVALID_HEADER				(0x10041108L)

#define PR_MTP_E_CH_INVALID_CHECKSUM			(0x10041109L)

#define PR_MTP_E_CH_UNABLE_TO_VERIFY			(0x1004110AL)

#define PR_MTP_E_CH_UNSUPPORTED_VERSION			(0x1004110BL)

#define PR_MTP_E_CH_UNSUPPORTED_HASH_ALGORITHM	(0x1004110CL)

#define PR_MTP_E_CH_UNSUPPORTED_SIGN_ALGORITHM	(0x1004110DL)

#define PR_MTP_E_CH_BAD_KEY						(0x1004110EL)

#define PR_MTP_E_CH_INCOMPATIBLE_HEADER_TYPE	(0x1004110FL)

#define PR_MTP_E_HEADER_ALREADY_SET				(0x10041110L)

#define PR_MTP_E_CH_NOT_SIGNED					(0x10041113L)

#define PR_MTP_E_CH_UNKNOWN_ERROR				(0x10041116L)

#define PR_MTP_LIC_BASECODE						(0x10041200L)

#define PR_MTP_LIC_INIT_FAILURE					(0x10041201L)

#define PR_MTP_LIC_LICENSE_NOTSET				(0x10041202L)

#define PR_MTP_LIC_PARAM_NOT_OPTIONAL			(0x10041203L)

#define PR_MTP_LIC_MEMORY_ALLOCATION_ERROR		(0x10041204L)

#define PR_MTP_LIC_INVALID_LICENSE				(0x10041205L)

#define PR_MTP_LIC_FIELD_MISSING				(0x10041206L)

#define PR_MTP_LIC_UNSUPPORTED_VALUE			(0x10041207L)

#define PR_MTP_LIC_UNKNOWN_ERROR				(0x10041208L)

#define PR_MTP_LIC_INVALID_REVLIST				(0x10041209L)

#define PR_MTP_LIC_EXPIRED_CERT					(0x1004120AL)

#define PR_MTP_CPRMEXP_BASECODE					(0x10041400L)

#define PR_MTP_CPRMEXP_PARAM_NOT_OPTIONAL		(0x10041401L)

#define PR_MTP_CPRMEXP_MEMORY_ALLOCATION_ERROR	(0x10041402L)

#define PR_MTP_CPRMEXP_NO_OPERANDS_IN_EXPRESSION	(0x10041403L)

#define PR_MTP_CPRMEXP_INVALID_TOKEN			(0x10041404L)

#define PR_MTP_CPRMEXP_INVALID_CONSTANT			(0x10041405L)

#define PR_MTP_CPRMEXP_INVALID_VARIABLE			(0x10041406L)

#define PR_MTP_CPRMEXP_INVALID_FUNCTION			(0x10041407L)

#define PR_MTP_CPRMEXP_INVALID_ARGUMENT			(0x10041408L)

#define PR_MTP_CPRMEXP_INVALID_CONTEXT			(0x10041409L)

#define PR_MTP_CPRMEXP_ENDOFBUFFER				(0x1004140AL)

#define PR_MTP_CPRMEXP_MISSING_OPERAND			(0x1004140BL)

#define PR_MTP_CPRMEXP_OVERFLOW					(0x1004140CL)

#define PR_MTP_CPRMEXP_UNDERFLOW				(0x1004140DL)

#define PR_MTP_CPRMEXP_INCORRECT_NUM_ARGS		(0x1004140EL)

#define PR_MTP_CPRMEXP_VARIABLE_EXPECTED		(0x1004140FL)

#define PR_MTP_CPRMEXP_RETRIEVAL_FAILURE		(0x10041410L)

#define PR_MTP_CPRMEXP_UPDATE_FAILURE			(0x10041411L)

#define PR_MTP_CPRMEXP_STRING_UNTERMINATED		(0x10041412L)

#define PR_MTP_CPRMEXP_UPDATE_UNSUPPORTED		(0x10041413L)

#define PR_MTP_CPRMEXP_ISOLATED_OPERAND_OR_OPERATOR	(0x10041414L)

#define PR_MTP_CPRMEXP_UNMATCHED				(0x10041415L)

#define PR_MTP_CPRMEXP_WRONG_TYPE_OPERAND		(0x10041416L)

#define PR_MTP_CPRMEXP_TOO_MANY_OPERANDS		(0x10041417L)

#define PR_MTP_CPRMEXP_UNKNOWN_PARSE_ERROR		(0x10041418L)

#define PR_MTP_CPRMEXP_UNSUPPORTED_FUNCTION		(0x10041419L)

#define PR_MTP_CPRMEXP_CLOCK_REQUIRED			(0x1004141AL)

#define PR_MTP_E_LEGACY_BASECODE				(0x10048000L)

#define PR_MTP_E_LIC_KEY_DECODE_FAILURE			(0x10048007L)

#define PR_MTP_E_LIC_SIGNATURE_FAILURE			(0x10048008L)

#define PR_MTP_E_LIC_KEY_AND_CERT_MISMATCH		(0x10048013L)

#define PR_MTP_E_KEY_MISMATCH					(0x10048014L)

#define PR_MTP_E_INVALID_SIGNATURE				(0x100480CFL)

#define PR_MTP_E_SYNC_ENTRYNOTFOUND				(0x100480D0L)

#define PR_MTP_E_STACKTOOSMALL					(0x100480D1L)

#define PR_MTP_E_CIPHER_NOTINITIALIZED			(0x100480D2L)

#define PR_MTP_E_DECRYPT_NOTINITIALIZED			(0x100480D3L)

#define PR_MTP_E_SECURESTORE_LOCKNOTOBTAINED	(0x100480D4L)

#define PR_MTP_E_PKCRYPTO_FAILURE				(0x100480D5L)

#define PR_MTP_E_INVALID_DSTSLOTSIZE			(0x100480D6L)

#define PR_MTP_DRMUTIL_BASECODE					(0x10049000L)

#define PR_MTP_DRMUTIL_UNSUPPORTED_VERSION		(0x10049005L)

#define PR_MTP_DRMUTIL_EXPIRED_CERT				(0x10049006L)

#define PR_MTP_DRMUTIL_INVALID_CERT				(0x10049007L)

#define PR_MTP_E_DEVICE_NOT_REGISTERED			(0x1004A000L)

#define PR_MTP_E_TOO_MANY_INCLUSION_GUIDS		(0x1004A001L)

#define PR_MTP_E_REVOCATION_GUID_NOT_RECOGNIZED	(0x1004A002L)

#define PR_MTP_E_LIC_CHAIN_TOO_DEEP				(0x1004A003L)

#define PR_MTP_E_DEVICE_SECURITY_LEVEL_TOO_LOW	(0x1004A004L)

#define PR_MTP_E_DST_BLOCK_CACHE_CORRUPT		(0x1004A005L)

#define PR_MTP_E_CONTRACT_FAILED				(0x1004A006L)

#define PR_MTP_E_DST_BLOCK_CACHE_MISS			(0x1004A007L)

#define PR_MTP_E_INVALID_METERRESPONSE_SIGNATURE	(0x1004A013L)

#define PR_MTP_E_INVALID_LICENSE_REVOCATION_LIST_SIGNATURE	(0x1004A014L)

#define PR_MTP_E_INVALID_METERCERT_SIGNATURE	(0x1004A015L)

#define PR_MTP_E_METERSTORE_DATA_NOT_FOUND		(0x1004A016L)

#define PR_MTP_E_NO_LICENSES_TO_SYNC			(0x1004A017L)

#define PR_MTP_E_INVALID_REVOCATION_LIST		(0x1004A018L)

#define PR_MTP_E_ENVELOPE_CORRUPT				(0x1004A019L)

#define PR_MTP_E_ENVELOPE_FILE_NOT_COMPATIBLE	(0x1004A01AL)

#define PR_MTP_E_EXTENDED_RESTRICTION_NOT_UNDERSTOOD	(0x1004A01BL)

#define PR_MTP_E_INVALID_SLK					(0x1004A01CL)

#define PR_MTP_E_DEVICENOTINIT					(0x1004C001L)

#define PR_MTP_E_DRMNOTINIT						(0x1004C002L)

#define PR_MTP_E_INVALIDRIGHT					(0x1004C003L)

#define PR_MTP_E_INCOMPATABLELICENSESIZE		(0x1004C004L)

#define PR_MTP_E_INVALIDLICENSEFLAGS			(0x1004C005L)

#define PR_MTP_E_INVALIDLICENSE					(0x1004C006L)

#define PR_MTP_E_CONDITIONFAIL					(0x1004C007L)

#define PR_MTP_E_CONDITIONNOTSUPPORTED			(0x1004C008L)

#define PR_MTP_E_LICENSEEXPIRED					(0x1004C009L)

#define PR_MTP_E_LICENSENOTYETVALID				(0x1004C00AL)

#define PR_MTP_E_RIGHTSNOTAVAILABLE				(0x1004C00BL)

#define PR_MTP_E_LICENSEMISMATCH				(0x1004C00CL)

#define PR_MTP_E_WRONGTOKENTYPE					(0x1004C00DL)

#define PR_MTP_E_NORIGHTSREQUESTED				(0x1004C00EL)

#define PR_MTP_E_LICENSENOTBOUND				(0x1004C00FL)

#define PR_MTP_E_HASHMISMATCH					(0x1004C010L)

#define PR_MTP_E_INVALIDTIME					(0x1004C011L)

#define PR_MTP_E_LICENSESTORENOTFOUND			(0x1004C012L)

#define PR_MTP_E_LICENSENOTFOUND				(0x1004C013L)

#define PR_MTP_E_LICENSEVERSIONNOTSUPPORTED		(0x1004C014L)

#define PR_MTP_E_INVALIDBINDID					(0x1004C015L)

#define PR_MTP_E_UNSUPPORTEDALGORITHM			(0x1004C016L)

#define PR_MTP_E_ALGORITHMNOTSET				(0x1004C017L)

#define PR_MTP_E_LICENSESERVERNEEDSKEY			(0x1004C018L)

#define PR_MTP_E_INVALIDLICENSESTORE			(0x1004C019L)

#define PR_MTP_E_FILEREADERROR					(0x1004C01AL)

#define PR_MTP_E_FILEWRITEERROR					(0x1004C01BL)

#define PR_MTP_E_CLIENTTIMEINVALID				(0x1004C01CL)

#define PR_MTP_E_DSTSTOREFULL					(0x1004C01DL)

#define PR_MTP_E_NOXMLOPENTAG					(0x1004C01EL)

#define PR_MTP_E_NOXMLCLOSETAG					(0x1004C01FL)

#define PR_MTP_E_INVALIDXMLTAG					(0x1004C020L)

#define PR_MTP_E_NOXMLCDATA						(0x1004C021L)

#define PR_MTP_E_DSTNAMESPACEFULL				(0x1004C022L)

#define PR_MTP_E_DSTNAMESPACENOTFOUND			(0x1004C023L)

#define PR_MTP_E_DSTSLOTNOTFOUND				(0x1004C024L)

#define PR_MTP_E_DSTSLOTEXIST					(0x1004C025L)

#define PR_MTP_E_DSTCORRUPTED					(0x1004C026L)

#define PR_MTP_E_DSTSEEKERROR					(0x1004C027L)

#define PR_MTP_E_DSTNAMESPACEINUSE				(0x1004C028L)

#define PR_MTP_E_INVALID_SECURESTORE_PASSWORD	(0x1004C029L)

#define PR_MTP_E_SECURESTORE_CORRUPT			(0x1004C02AL)

#define PR_MTP_E_SECURESTORE_FULL				(0x1004C02BL)

#define PR_MTP_E_NOACTIONINLICENSEREQUEST		(0x1004C02CL)

#define PR_MTP_E_DUPLICATEDHEADERATTRIBUTE		(0x1004C02DL)

#define PR_MTP_E_NOKIDINHEADER					(0x1004C02EL)

#define PR_MTP_E_NOLAINFOINHEADER				(0x1004C02FL)

#define PR_MTP_E_NOCHECKSUMINHEADER				(0x1004C030L)

#define PR_MTP_E_DSTBLOCKMISMATCH				(0x1004C031L)

#define PR_MTP_E_BACKUP_EXISTS					(0x1004C032L)

#define PR_MTP_E_LICENSE_TOOLONG				(0x1004C033L)

#define PR_MTP_E_DSTEXISTS						(0x1004C034L)

#define PR_MTP_E_INVALIDDEVICECERTIFICATE		(0x1004C035L)

#define PR_MTP_E_DSTLOCKFAILED					(0x1004C036L)

#define PR_MTP_E_FILESEEKERROR					(0x1004C037L)

#define PR_MTP_E_DSTNOTLOCKEDEXCLUSIVE			(0x1004C038L)

#define PR_MTP_E_DSTEXCLUSIVELOCKONLY			(0x1004C039L)

#define PR_MTP_E_DSTRESERVEDKEYDETECTED			(0x1004C03AL)

#define PR_MTP_E_V1_NOT_SUPPORTED				(0x1004C03BL)

#define PR_MTP_E_HEADER_NOT_SET					(0x1004C03CL)

#define PR_MTP_E_NEEDDEVCERTINDIV				(0x1004C03DL)

#define PR_MTP_E_MACHINEIDMISMATCH				(0x1004C03EL)

#define PR_MTP_E_CLK_INVALID_RESPONSE			(0x1004C03FL)

#define PR_MTP_E_CLK_INVALID_DATE				(0x1004C040L)

#define PR_MTP_E_CLK_UNSUPPORTED_VALUE			(0x1004C041L)

#define PR_MTP_E_INVALIDDEVICECERTIFICATETEMPLATE	(0x1004C042L)

#define PR_MTP_E_DEVCERTEXCEEDSIZELIMIT			(0x1004C043L)

#define PR_MTP_E_DEVCERTTEMPLATEEXCEEDSSIZELIMIT	(0x1004C044L)

#define PR_MTP_E_DEVCERTREADERROR				(0x1004C045L)

#define PR_MTP_E_DEVCERTWRITEERROR				(0x1004C046L)

#define PR_MTP_E_PRIVKEYREADERROR				(0x1004C047L)

#define PR_MTP_E_PRIVKEYWRITEERROR				(0x1004C048L)

#define PR_MTP_E_DEVCERTTEMPLATEREADERROR		(0x1004C049L)

#define PR_MTP_E_CLK_NOT_SUPPORTED				(0x1004C04AL)

#define PR_MTP_E_DEVCERTINDIV_NOT_SUPPORTED		(0x1004C04BL)

#define PR_MTP_E_METERING_NOT_SUPPORTED			(0x1004C04CL)

#define PR_MTP_E_CLK_RESETSTATEREADERROR		(0x1004C04DL)

#define PR_MTP_E_CLK_RESETSTATEWRITEERROR		(0x1004C04EL)

#define PR_MTP_E_XMLNOTFOUND					(0x1004C04FL)

#define PR_MTP_E_METERING_WRONG_TID				(0x1004C050L)

#define PR_MTP_E_METERING_INVALID_COMMAND		(0x1004C051L)

#define PR_MTP_E_METERING_STORE_CORRUPT			(0x1004C052L)

#define PR_MTP_E_CERTIFICATE_REVOKED			(0x1004C053L)

#define PR_MTP_E_CRYPTO_FAILED					(0x1004C054L)

#define PR_MTP_E_STACK_CORRUPT					(0x1004C055L)

#define PR_MTP_E_UNKNOWN_BINDING_KEY			(0x1004C056L)

#define PR_MTP_E_V1_LICENSE_CHAIN_NOT_SUPPORTED	(0x1004C057L)

#define PR_MTP_E_WRONG_TOKEN_TYPE				(0x1004C058L)

#define PR_MTP_E_POLICY_METERING_DISABLED		(0x1004C059L)

#define PR_MTP_E_POLICY_ONLINE_DISABLED			(0x1004C05AL)

#define PR_MTP_E_CLK_NOT_SET					(0x1004C05BL)

#define PR_MTP_E_NO_CLK_SUPPORTED				(0x1004C05CL)

#define PR_MTP_E_NO_URL							(0x1004C05DL)

#define PR_MTP_E_UNKNOWN_DEVICE_PROPERTY		(0x1004C05EL)

#define PR_MTP_E_METERING_MID_MISMATCH			(0x1004C05FL)

#define PR_MTP_E_METERING_RESPONSE_DECRYPT_FAILED	(0x1004C060L)

#define PR_MTP_E_RIV_TOO_SMALL					(0x1004C063L)

#define PR_MTP_E_STACK_ALREADY_INITIALIZED		(0x1004C064L)

#define PR_MTP_E_DEVCERT_REVOKED				(0x1004C065L)

#define PR_MTP_E_OEM_RSA_DECRYPTION_ERROR		(0x1004C066L)

#define PR_MTP_E_INVALID_DEVSTORE_ATTRIBUTE		(0x1004C067L)

#define PR_MTP_E_INVALID_DEVSTORE_ENTRY			(0x1004C068L)

#define PR_MTP_E_OEM_RSA_ENCRYPTION_ERROR		(0x1004C069L)

#define PR_MTP_E_DSTNAMESPACEEXIST				(0x1004C06AL)

#define PR_MTP_E_PERF_SCOPING_ERROR				(0x1004C06BL)

#define PR_MTP_E_PRECISION_ARITHMETIC_FAIL		(0x1004C06CL)

#define PR_MTP_E_OEM_RSA_INVALID_PRIVATE_KEY	(0x1004C06DL)

#define PR_MTP_E_NO_OPL_CALLBACK				(0x1004C06EL)

#define PR_MTP_E_INVALID_PLAYREADY_OBJECT		(0x1004C06FL)

#define PR_MTP_E_DUPLICATE_LICENSE				(0x1004C070L)

#define PR_MTP_E_REVOCATION_NOT_SUPPORTED		(0x1004C071L)

#define PR_MTP_E_RECORD_NOT_FOUND				(0x1004C072L)

#define PR_MTP_E_BUFFER_BOUNDS_EXCEEDED			(0x1004C073L)

#define PR_MTP_E_LRB_BASECODE					(PR_MTP_E_BASECODE+0xA0)

#define PR_MTP_E_LRB_NOLGPUBKEY					(0x1004C0A0L)

#define PR_MTP_E_LRB_INVALIDSIGNATURE			(0x1004C0A1L)

#define PR_MTP_E_LRB_LGPUBKEY_MISMATCH			(0x1004C0A2L)

#define PR_MTP_E_LRB_INVALIDLICENSEDATA			(0x1004C0A3L)

#define PR_MTP_E_LICEVAL_BASECODE				(PR_MTP_E_BASECODE+0xC0)

#define PR_MTP_E_LICEVAL_LICENSE_NOT_SUPPLIED	(0x1004C0C0L)

#define PR_MTP_E_LICEVAL_KID_MISMATCH			(0x1004C0C1L)

#define PR_MTP_E_LICEVAL_LICENSE_REVOKED		(0x1004C0C2L)

#define PR_MTP_E_LICEVAL_UPDATE_FAILURE			(0x1004C0C3L)

#define PR_MTP_E_LICEVAL_REQUIRED_REVOCATION_LIST_NOT_AVAILABLE	(0x1004C0C4L)

#define PR_MTP_E_XMR_BASECODE					(PR_MTP_E_BASECODE+0xE0)

#define PR_MTP_E_XMR_OBJECT_ALREADY_EXISTS		(0x1004C0E0L)

#define PR_MTP_E_XMR_OBJECT_NOTFOUND			(0x1004C0E1L)

#define PR_MTP_E_XMR_REQUIRED_OBJECT_MISSING	(0x1004C0E2L)

#define PR_MTP_E_XMR_INVALID_UNKNOWN_OBJECT		(0x1004C0E3L)

#define PR_MTP_E_XMR_LICENSE_BINDABLE			(0x1004C0E4L)

#define PR_MTP_E_XMR_LICENSE_NOT_BINDABLE		(0x1004C0E5L)

#define PR_MTP_E_XMR_UNSUPPORTED_XMR_VERSION	(0x1004C0E6L)

#define PR_MTP_E_CRL_BASECODE					(PR_MTP_E_BASECODE+0x100)

#define PR_MTP_E_NOT_CRL_BLOB					(0x1004C100L)

#define PR_MTP_E_BAD_CRL_BLOB					(0x1004C101L)

#define PR_MTP_E_CERT_BASECODE					(PR_MTP_E_BASECODE+0x200)

#define PR_MTP_E_INVALID_DEVCERT_ATTRIBUTE		(0x1004C200L)

#define PR_MTP_E_TEST_BASECODE					(PR_MTP_E_BASECODE+0x300)

#define PR_MTP_S_TEST_BASECODE					(PR_MTP_S_BASECODE+0x300)

#define PR_MTP_S_TEST_SKIP_FILE					(0x0004C300L)

#define PR_MTP_E_TEST_PKCRYPTO_FAILURE			(0x1004C300L)

#define PR_MTP_E_TEST_PKSIGN_VERIFY_ERROR		(0x1004C301L)

#define PR_MTP_E_TEST_ENCRYPT_ERROR				(0x1004C302L)

#define PR_MTP_E_TEST_RC4KEY_FAILED				(0x1004C303L)

#define PR_MTP_E_TEST_DECRYPT_ERROR				(0x1004C304L)

#define PR_MTP_E_TEST_DESKEY_FAILED				(0x1004C305L)

#define PR_MTP_E_TEST_CBC_INVERSEMAC_FAILURE	(0x1004C306L)

#define PR_MTP_E_TEST_HMAC_FAILURE				(0x1004C307L)

#define PR_MTP_E_TEST_INVALIDARG				(0x1004C308L)

#define PR_MTP_E_TEST_DEVICE_PRIVATE_KEY_INCORRECTLY_STORED	(0x1004C30AL)

#define PR_MTP_E_TEST_DRMMANAGER_CONTEXT_NULL	(0x1004C30BL)

#define PR_MTP_E_TEST_UNEXPECTED_REVINFO_RESULT	(0x1004C30CL)

#define PR_MTP_E_TEST_RIV_MISMATCH				(0x1004C30DL)

#define PR_MTP_E_TEST_URL_ERROR					(0x1004C310L)

#define PR_MTP_E_TEST_MID_MISMATCH				(0x1004C311L)

#define PR_MTP_E_TEST_METER_CERTIFICATE_MISMATCH	(0x1004C312L)

#define PR_MTP_E_TEST_LICENSE_STATE_MISMATCH	(0x1004C313L)

#define PR_MTP_E_TEST_SOURCE_ID_MISMATCH		(0x1004C316L)

#define PR_MTP_E_TEST_UNEXPECTED_LICENSE_COUNT	(0x1004C317L)

#define PR_MTP_E_TEST_UNEXPECTED_DEVICE_PROPERTY	(0x1004C318L)

#define PR_MTP_E_TEST_DRMMANAGER_MISALIGNED_BYTES	(0x1004C319L)

#define PR_MTP_E_TEST_LICENSE_RESPONSE_ERROR	(0x1004C31AL)

#define PR_MTP_E_TEST_OPL_MISMATCH				(0x1004C31BL)

#define PR_MTP_E_TEST_INVALID_OPL_CALLBACK		(0x1004C31CL)

#define PR_MTP_E_TEST_INCOMPLETE				(0x1004C31DL)

#define PR_MTP_E_TEST_UNEXPECTED_OUTPUT			(0x1004C31EL)

#define PR_MTP_E_TEST_DLA_NO_CONTENT_HEADER		(0x1004C31FL)

#define PR_MTP_E_TEST_DLA_CONTENT_HEADER_FOUND	(0x1004C320L)

#define PR_MTP_E_TEST_SYNC_LSD_INCORRECT		(0x1004C321L)

#define PR_MTP_E_TEST_TOO_SLOW					(0x1004C322L)

#define PR_MTP_E_TEST_LICENSESTORE_NOT_OPEN		(0x1004C323L)

#define PR_MTP_E_TEST_DEVICE_NOT_INITED			(0x1004C324L)

#define PR_MTP_E_TEST_VARIABLE_NOT_SET			(0x1004C325L)

#define PR_MTP_E_TEST_NOMORE					(0x1004C326L)

#define PR_MTP_E_TEST_FILE_LOAD_ERROR			(0x1004C327L)

#define PR_MTP_E_TEST_LICENSE_ACQ_FAILED		(0x1004C328L)

#define PR_MTP_E_TEST_UNSUPPORTED_FILE_FORMAT	(0x1004C329L)

#define PR_MTP_E_TEST_PARSING_ERROR				(0x1004C32AL)

#define PR_MTP_E_TEST_NOTIMPL					(0x1004C32BL)

#define PR_MTP_E_TEST_VARIABLE_NOTFOUND			(0x1004C32CL)

#define PR_MTP_E_TEST_VARIABLE_LISTFULL			(0x1004C32DL)

#define PR_MTP_E_TEST_UNEXPECTED_CONTENT_PROPERTY	(0x1004C32EL)

#define PR_MTP_E_TEST_PRO_HEADER_NOT_SET		(0x1004C32FL)

#define PR_MTP_E_TEST_NON_PRO_HEADER_TYPE		(0x1004C330L)

#define PR_MTP_E_TEST_INVALID_DEVICE_WRAPPER	(0x1004C331L)

#define PR_MTP_E_TEST_INVALID_WMDM_WRAPPER		(0x1004C332L)

#define PR_MTP_E_TEST_INVALID_WPD_WRAPPER		(0x1004C333L)

#define PR_MTP_E_TEST_INVALID_FILE				(0x1004C334L)

#define PR_MTP_E_TEST_PROPERTY_NOT_FOUND		(0x1004C335L)

#define PR_MTP_E_TEST_METERING_DATA_INCORRECT	(0x1004C336L)

#define PR_MTP_E_TEST_FILE_ALREADY_OPEN			(0x1004C337L)

#define PR_MTP_E_TEST_FILE_NOT_OPEN				(0x1004C338L)

#define PR_MTP_E_TEST_PICT_COLUMN_TOO_WIDE		(0x1004C339L)

#define PR_MTP_E_TEST_PICT_COLUMN_MISMATCH		(0x1004C33AL)

#define PR_MTP_E_LOGICERR						(0x1004C3E8L)

#define PR_MTP_E_INVALIDREVINFO					(0x1004C3E9L)

#define PR_MTP_E_SYNCLISTNOTSUPPORTED			(0x1004C3EAL)

#define PR_MTP_E_REVOCATION_BUFFERTOOSMALL		(0x1004C3EBL)

#define PR_MTP_E_DEVICE_ALREADY_REGISTERED		(0x1004C3ECL)

#define PR_MTP_E_DST_NOT_COMPATIBLE				(0x1004C3EDL)

#define PR_MTP_E_RSA_DECRYPTION_ERROR			(0x1004C3F0L)

#define PR_MTP_E_OEM_RSA_MESSAGE_TOO_BIG		(0x1004C3F1L)

#define PR_MTP_E_METERCERTNOTFOUND				(0x1004C3F2L)

#define PR_MTP_E_MODULAR_ARITHMETIC_FAILURE		(0x1004C3F3L)

#define PR_MTP_E_FEATURE_NOT_SUPPORTED			(0x1004C3F4L)

#define PR_MTP_E_REVOCATION_INVALID_PACKAGE		(0x1004C3F5L)

#define PR_MTP_E_DOMAIN_BASECODE				(PR_MTP_E_BASECODE + 0x500)

#define PR_MTP_E_DOMAIN_INVALID_GUID			(0x1004C500L)

#define PR_MTP_E_DOMAIN_INVALID_CUSTOM_DATA_TYPE	(0x1004C501L)

#define PR_MTP_E_DOMAIN_STORE_ADD_DATA			(0x1004C502L)

#define PR_MTP_E_DOMAIN_STORE_GET_DATA			(0x1004C503L)

#define PR_MTP_E_DOMAIN_STORE_DELETE_DATA		(0x1004C504L)

#define PR_MTP_E_DOMAIN_STORE_OPEN_STORE		(0x1004C505L)

#define PR_MTP_E_DOMAIN_STORE_CLOSE_STORE		(0x1004C506L)

#define PR_MTP_E_DOMAIN_BIND_LICENSE			(0x1004C507L)

#define PR_MTP_E_DOMAIN_INVALID_CUSTOM_DATA		(0x1004C508L)

#define PR_MTP_E_DOMAIN_NOT_FOUND				(0x1004C509L)

#define PR_MTP_E_DOMAIN_INVALID_DOMKEYXMR_DATA	(0x1004C50AL)

#define PR_MTP_E_PC_BASECODE					(PR_MTP_E_BASECODE + 0x580)

#define PR_MTP_E_DEVICE_DOMAIN_JOIN_REQUIRED	(0x1004C580L)

#define PR_MTP_E_SERVER_BASECODE				(PR_MTP_E_BASECODE + 0x600)

#define PR_MTP_E_SERVER_INTERNAL_ERROR			(0x1004C600L)

#define PR_MTP_E_SERVER_INVALID_MESSAGE			(0x1004C601L)

#define PR_MTP_E_SERVER_DEVICE_LIMIT_REACHED	(0x1004C602L)

#define PR_MTP_E_SERVER_INDIV_REQUIRED			(0x1004C603L)

#define PR_MTP_E_SERVER_SERVICE_SPECIFIC		(0x1004C604L)

#define PR_MTP_E_SERVER_DOMAIN_REQUIRED			(0x1004C605L)

#define PR_MTP_E_SERVER_RENEW_DOMAIN			(0x1004C606L)

#define PR_MTP_E_SERVER_UNKNOWN_METERINGID		(0x1004C607L)

#define PR_MTP_E_SERVER_COMPUTER_LIMIT_REACHED	(0x1004C608L)

#define PR_MTP_E_SERVER_PROTOCOL_FALLBACK		(0x1004C609L)

#define PR_MTP_E_SERVER_NOT_A_MEMBER			(0x1004C60AL)

#define PR_MTP_E_SERVER_PROTOCOL_VERSION_MISMATCH	(0x1004C60BL)

#define PR_MTP_E_SERVER_UNKNOWN_ACCOUNTID		(0x1004C60CL)

#define PR_MTP_E_SERVER_PROTOCOL_REDIRECT		(0x1004C60DL)

#define PR_MTP_E_SERVICES_BASECODE				(PR_MTP_E_BASECODE + 0x680)

#define PR_MTP_E_LICACQ_BASECODE				(PR_MTP_E_BASECODE + 0x700)

#define PR_MTP_E_LICACQ_TOO_MANY_LICENSES		(0x1004C700L)

#define PR_MTP_E_LICACQ_ACK_TRANSACTIONID_TOO_BIG	(0x1004C701L)

#define PR_MTP_E_LICACQ_ACK_MESSAGE_NOT_CREATED	(0x1004C702L)

#define PR_MTP_E_INITIATORS_BASECODE			(PR_MTP_E_BASECODE + 0x780)

#define PR_MTP_E_INITIATORS_UNKNOWN_TYPE		(0x1004C780L)

#define PR_MTP_E_INITIATORS_INVALID_SERVICEID	(0x1004C781L)

#define PR_MTP_E_INITIATORS_INVALID_ACCOUNTID	(0x1004C782L)

#define PR_MTP_E_INITIATORS_INVALID_MID			(0x1004C783L)

#define PR_MTP_E_INITIATORS_MISSING_DC_URL		(0x1004C784L)

#define PR_MTP_E_INITIATORS_MISSING_CONTENT_HEADER	(0x1004C785L)

#define PR_MTP_E_INITIATORS_MISSING_LAURL_IN_CONTENT_HEADER	(0x1004C786L)

#define PR_MTP_E_INITIATORS_MISSING_METERCERT_URL	(0x1004C787L)

#define PR_MTP_E_BCERT_BASECODE					(PR_MTP_E_BASECODE + 0x100)

#define PR_MTP_E_BCERT_INVALID_SIGNATURE_TYPE	(0x1004C800L)

#define PR_MTP_E_BCERT_CHAIN_TOO_DEEP			(0x1004C801L)

#define PR_MTP_E_BCERT_INVALID_CERT_TYPE		(0x1004C802L)

#define PR_MTP_E_BCERT_INVALID_FEATURE			(0x1004C803L)

#define PR_MTP_E_BCERT_INVALID_KEY_USAGE		(0x1004C804L)

#define PR_MTP_E_BCERT_INVALID_SECURITY_VERSION	(0x1004C805L)

#define PR_MTP_E_BCERT_INVALID_KEY_TYPE			(0x1004C806L)

#define PR_MTP_E_BCERT_INVALID_KEY_LENGTH		(0x1004C807L)

#define PR_MTP_E_BCERT_INVALID_MAX_LICENSE_SIZE	(0x1004C808L)

#define PR_MTP_E_BCERT_INVALID_MAX_HEADER_SIZE	(0x1004C809L)

#define PR_MTP_E_BCERT_INVALID_MAX_LICENSE_CHAIN_DEPTH	(0x1004C80AL)

#define PR_MTP_E_BCERT_INVALID_SECURITY_LEVEL	(0x1004C80BL)

#define PR_MTP_E_BCERT_PRIVATE_KEY_NOT_SPECIFIED	(0x1004C80CL)

#define PR_MTP_E_BCERT_ISSUER_KEY_NOT_SPECIFIED	(0x1004C80DL)

#define PR_MTP_E_BCERT_ACCOUNT_ID_NOT_SPECIFIED	(0x1004C80EL)

#define PR_MTP_E_BCERT_SERVICE_ID_NOT_SPECIFIED	(0x1004C80FL)

#define PR_MTP_E_BCERT_CLIENT_ID_NOT_SPECIFIED	(0x1004C810L)

#define PR_MTP_E_BCERT_DOMAIN_URL_NOT_SPECIFIED	(0x1004C811L)

#define PR_MTP_E_BCERT_DOMAIN_URL_TOO_LONG		(0x1004C812L)

#define PR_MTP_E_BCERT_HARDWARE_ID_NOT_SPECIFIED	(0x1004C813L)

#define PR_MTP_E_BCERT_HARDWARE_ID_TOO_LONG		(0x1004C814L)

#define PR_MTP_E_BCERT_SERIAL_NUM_NOT_SPECIFIED	(0x1004C815L)

#define PR_MTP_E_BCERT_CERT_ID_NOT_SPECIFIED	(0x1004C816L)

#define PR_MTP_E_BCERT_PUBLIC_KEY_NOT_SPECIFIED	(0x1004C817L)

#define PR_MTP_E_BCERT_KEY_USAGES_NOT_SPECIFIED	(0x1004C818L)

#define PR_MTP_E_BCERT_STRING_NOT_NULL_TERMINATED	(0x1004C819L)

#define PR_MTP_E_BCERT_OBJECTHEADER_LEN_TOO_BIG	(0x1004C81AL)

#define PR_MTP_E_BCERT_INVALID_ISSUERKEY_LENGTH	(0x1004C81BL)

#define PR_MTP_E_BCERT_BASICINFO_CERT_EXPIRED	(0x1004C81CL)

#define PR_MTP_E_BCERT_UNEXPECTED_OBJECT_HEADER	(0x1004C81DL)

#define PR_MTP_E_BCERT_ISSUERKEY_KEYINFO_MISMATCH	(0x1004C81EL)

#define PR_MTP_E_BCERT_INVALID_MAX_KEY_USAGES	(0x1004C81FL)

#define PR_MTP_E_BCERT_INVALID_MAX_FEATURES		(0x1004C820L)

#define PR_MTP_E_BCERT_INVALID_CHAIN_HEADER_TAG	(0x1004C821L)

#define PR_MTP_E_BCERT_INVALID_CHAIN_VERSION	(0x1004C822L)

#define PR_MTP_E_BCERT_INVALID_CHAIN_LENGTH		(0x1004C823L)

#define PR_MTP_E_BCERT_INVALID_CERT_HEADER_TAG	(0x1004C824L)

#define PR_MTP_E_BCERT_INVALID_CERT_VERSION		(0x1004C825L)

#define PR_MTP_E_BCERT_INVALID_CERT_LENGTH		(0x1004C826L)

#define PR_MTP_E_BCERT_INVALID_SIGNEDCERT_LENGTH	(0x1004C827L)

#define PR_MTP_E_BCERT_INVALID_PLATFORM_IDENTIFIER	(0x1004C828L)

#define PR_MTP_E_BCERT_INVALID_NUMBER_EXTDATARECORDS	(0x1004C829L)

#define PR_MTP_E_BCERT_INVALID_EXTDATARECORD	(0x1004C82AL)

#define PR_MTP_BCERT_EXTDATA_LENGTH_MUST_PRESENT	(0x1004C82BL)

#define PR_MTP_BCERT_EXTDATA_PRIVKEY_MUST_PRESENT	(0x1004C82CL)

#define PR_MTP_E_BCERT_INVALID_EXTDATA_LENGTH	(0x1004C82DL)

#define PR_MTP_E_BCERT_EXTDATA_IS_NOT_PROVIDED	(0x1004C82EL)

#define PR_MTP_E_BCERT_HWIDINFO_IS_MISSING		(0x1004C82FL)

#define PR_MTP_E_BCERT_INVALID_EXTDATA_SIGNED_LENGTH	(0x1004C830L)

#define PR_MTP_E_BCERT_INVALID_EXTDATA_RECORD_TYPE	(0x1004C831L)

#define PR_MTP_E_BCERT_EXTDATAFLAG_CERT_TYPE_MISMATCH	(0x1004C832L)

#define PR_MTP_E_BCERT_METERING_ID_NOT_SPECIFIED	(0x1004C833L)

#define PR_MTP_E_BCERT_METERING_URL_NOT_SPECIFIED	(0x1004C834L)

#define PR_MTP_E_BCERT_METERING_URL_TOO_LONG	(0x1004C835L)

#define PR_MTP_E_BCERT_VERIFICATION_ERRORS		(0x1004C836L)

#define PR_MTP_E_BCERT_REQUIRED_KEYUSAGE_MISSING	(0x1004C837L)

#define PR_MTP_E_BCERT_NO_PUBKEY_WITH_REQUESTED_KEYUSAGE	(0x1004C838L)

#define PR_MTP_E_BCERT_MANUFACTURER_STRING_TOO_LONG	(0x1004C839L)

#define PR_MTP_E_BCERT_TOO_MANY_PUBLIC_KEYS		(0x1004C83AL)

#define PR_MTP_E_BCERT_OBJECTHEADER_LEN_TOO_SMALL	(0x1004C83BL)

#define PR_MTP_E_BCERT_INVALID_WARNING_DAYS		(0x1004C83CL)

#define PR_MTP_E_XMLSIG_BASECODE				(PR_MTP_E_BASECODE + 0x900)

#define PR_MTP_E_XMLSIG_ECDSA_VERIFY_FAILURE	(0x1004C900L)

#define PR_MTP_E_XMLSIG_SHA_VERIFY_FAILURE		(0x1004C901L)

#define PR_MTP_E_XMLSIG_FORMAT					(0x1004C902L)

#define PR_MTP_E_XMLSIG_PUBLIC_KEY_ID			(0x1004C903L)

#define PR_MTP_E_XMLSIG_INVALID_KEY_FORMAT		(0x1004C904L)

#define PR_MTP_E_XMLSIG_SHA_HASH_SIZE			(0x1004C905L)

#define PR_MTP_E_XMLSIG_ECDSA_SIGNATURE_SIZE	(0x1004C906L)

#define PR_MTP_E_UTF_BASECODE					(PR_MTP_E_BASECODE + 0xa00)

#define PR_MTP_E_UTF_UNEXPECTED_END				(0x1004CA00L)

#define PR_MTP_E_UTF_INVALID_CODE				(0x1004CA01L)

#define PR_MTP_E_SOAPXML_BASECODE				(PR_MTP_E_BASECODE + 0xb00)

#define PR_MTP_E_SOAPXML_INVALID_STATUS_CODE	(0x1004CB00L)

#define PR_MTP_E_SOAPXML_XML_FORMAT				(0x1004CB01L)

#define PR_MTP_E_SOAPXML_WRONG_MESSAGE_TYPE		(0x1004CB02L)

#define PR_MTP_E_SOAPXML_SIGNATURE_MISSING		(0x1004CB03L)

#define PR_MTP_E_SOAPXML_PROTOCOL_NOT_SUPPORTED	(0x1004CB04L)

#define PR_MTP_E_CRYPTO_BASECODE				(PR_MTP_E_BASECODE + 0xc00)

#define PR_MTP_E_CRYPTO_PUBLIC_KEY_NOT_MATCH	(0x1004CC00L)

#define PR_MTP_E_SECURETRACE_BASECODE			(PR_MTP_E_BASECODE + 0xd00)

#define PR_MTP_E_SECURE_TRACE_BAD_GLOBAL_DATA_POINTER	(0x1004CD00L)

#define PR_MTP_E_SECURE_TRACE_INVALID_GLOBAL_DATA	(0x1004CD01L)

#define PR_MTP_E_SECURE_TRACE_FORMATTING_ERROR	(0x1004CD02L)

#define PR_MTP_E_SECURE_TRACE_BAD_SCHEME_DATA_POINTER	(0x1004CD03L)

#define PR_MTP_E_SECURE_TRACE_BAD_PER_THREAD_AES_DATA_POINTER	(0x1004CD04L)

#define PR_MTP_E_SECURE_TRACE_BAD_PER_THREAD_AES_BUFFER_POINTER	(0x1004CD05L)

#define PR_MTP_E_SECURE_TRACE_AES_INSUFFICIENT_BUFFER	(0x1004CD06L)

#define PR_MTP_E_SECURE_TRACE_VERSION_MISMATCH	(0x1004CD07L)

#define PR_MTP_E_SECURE_TRACE_UNEXPECTED_ERROR	(0x1004CD08L)

#define PR_MTP_ND_BASECODE						(PR_MTP_E_BASECODE + 0xE00)

#define PR_MTP_E_ND_MUST_REVALIDATE				(0x1004CE00L)

#define PR_MTP_E_ND_INVALID_MESSAGE				(0x1004CE01L)

#define PR_MTP_E_ND_INVALID_MESSAGE_TYPE		(0x1004CE02L)

#define PR_MTP_E_ND_INVALID_MESSAGE_VERSION		(0x1004CE03L)

#define PR_MTP_E_ND_INVALID_SESSION				(0x1004CE04L)

#define PR_MTP_E_ND_MEDIA_SESSION_LIMIT_REACHED	(0x1004CE05L)

#define PR_MTP_E_ND_UNABLE_TO_VERIFY_PROXIMITY	(0x1004CE06L)

#define PR_MTP_E_ND_INVALID_PROXIMITY_RESPONSE	(0x1004CE07L)

#define PR_MTP_E_ND_DEVICE_LIMIT_REACHED		(0x1004CE08L)

#define PR_MTP_E_ND_BAD_REQUEST					(0x1004CE09L)

#define PR_MTP_E_ND_FAILED_SEEK					(0x1004CE0AL)

#define PR_MTP_E_ND_INVALID_CONTEXT				(0x1004CE0BL)

#define PR_MTP_ASF_BASECODE						(PR_MTP_E_BASECODE + 0xF00)

#define PR_MTP_E_ASF_BAD_ASF_HEADER				(0x1004CF00L)

#define PR_MTP_E_ASF_BAD_PACKET_HEADER			(0x1004CF01L)

#define PR_MTP_E_ASF_BAD_PAYLOAD_HEADER			(0x1004CF02L)

#define PR_MTP_E_ASF_BAD_DATA_HEADER			(0x1004CF03L)

#define PR_MTP_E_ASF_INVALID_OPERATION			(0x1004CF04L)

#define PR_MTP_E_ASF_AES_PAYLOAD_FOUND			(0x1004CF05L)

#define PR_MTP_E_ASF_INVALID_DATA				(0x1004CF20L)

#define PR_MTP_E_ASF_TOO_MANY_PAYLOADS			(0x1004CF21L)

#define PR_MTP_E_ASF_BANDWIDTH_OVERRUN			(0x1004CF22L)

#define PR_MTP_E_ASF_INVALID_STREAM_NUMBER		(0x1004CF23L)

#define PR_MTP_E_ASF_LATE_SAMPLE				(0x1004CF24L)

#define PR_MTP_E_ASF_NOT_ACCEPTING				(0x1004CF25L)

#define PR_MTP_E_ASF_UNEXPECTED					(0x1004CF26L)

#define PR_MTP_E_NONCE_STORE_BASECODE			(PR_MTP_E_BASECODE + 0x1000)

#define PR_MTP_E_NONCE_STORE_TOKEN_NOT_FOUND	(0x1004D000L)

#define PR_MTP_E_NONCE_STORE_OPEN_STORE			(0x1004D001L)

#define PR_MTP_E_NONCE_STORE_CLOSE_STORE		(0x1004D002L)

#define PR_MTP_E_NONCE_STORE_ADD_LICENSE		(0x1004D003L)

#define PR_MTP_E_LICGEN_BASECODE				(PR_MTP_E_BASECODE+0x1100)

#define PR_MTP_E_LICGEN_POLICY_NOT_SUPPORTED	(0x1004D100L)

typedef enum {
	DRM_MTP_FALSE = 0,			  /**<false*/
	DRM_MTP_TRUE = 1,			  /**<true */
} DRM_MTP_BOOL;

typedef enum {
	PR_DRM_LICENSE_STATE_NORIGHT = 0,
	PR_DRM_LICENSE_STATE_UNLIM,
	PR_DRM_LICENSE_STATE_COUNT,
	PR_DRM_LICENSE_STATE_FROM,
	PR_DRM_LICENSE_STATE_UNTIL,
	PR_DRM_LICENSE_STATE_FROM_UNTIL,
	PR_DRM_LICENSE_STATE_COUNT_FROM,
	PR_DRM_LICENSE_STATE_COUNT_UNTIL,
	PR_DRM_LICENSE_STATE_COUNT_FROM_UNTIL,
	PR_DRM_LICENSE_STATE_EXPIRATION_AFTER_FIRSTUSE,
	PR_DRM_LICENSE_STATE_FORCE_SYNC,
} PR_DRM_LICENSE_STATE_CATEGORY;

typedef struct {
	unsigned int MaxCountRemaining;
	unsigned int MaxHoursRemaining;
	unsigned int StartingIndex;
	unsigned int ItemsToProcess;

} PR_SyncListRequestData;

typedef struct {
	unsigned char *pMtpData;
	unsigned int lenMtpData;
	unsigned int NextStartingIndex;
	unsigned int ItemsProcessed;
} PR_SyncListResponseData;

typedef struct {
	unsigned int OperationCode;
	unsigned int RequestArgument1;
	unsigned int RequestArgument2;
	unsigned int RequestArgument3;
	unsigned int RequestArgument4;
} PR_WMDRMPDRequestData;

typedef struct {
	unsigned int ResponseResult1;
	unsigned int ResponseResult2;
	unsigned int ResponseResult3;
	unsigned int ResponseResult4;
} PR_WMDRMPDResponseData;

typedef struct {
	unsigned char RequestFlags;
	unsigned int AccountID1;
	unsigned int AccountID2;
	unsigned int AccountID3;
	unsigned int AccountID4;
} PR_DomainCertRequestData;

typedef struct {
	unsigned int DevicePropCode;
	unsigned int DataType;
	unsigned char GetSet;
	unsigned long DefaultValue;
	unsigned char *pMtpData;
	unsigned int lenMtpData;
	unsigned long GroupCode;
	unsigned char FormFlag;

} PR_DevicePropDesc;

#ifdef __cplusplus
}
#endif
#endif				/* __DRM_PR_MTP_TYPES_H__ */
