/*
 *
 * Copyright (c) 2000 - 2012 Samsung Electronics Co., Ltd All Rights Reserved
 * This file is part of drm-service
 * Written by Hakjoo Ko <hakjoo.ko@samsung.com>
 * 
 * PROPRIETARY/CONFIDENTIAL
 *
 * This software is the confidential and proprietary information of
 * SAMSUNG ELECTRONICS ("Confidential Information"). You shall not 
 * disclose such Confidential Information and shall use it only in 
 * accordance with the terms of the license agreement you entered 
 * into with SAMSUNG ELECTRONICS.
 * SAMSUNG make no representations or warranties about the suitability
 * of the software, either express or implied, including but not limited
 * to the implied warranties of merchantability, fitness for a particular 
 * purpose, or non-infringement. SAMSUNG shall not be liable for any 
 * damages suffered by licensee as a result of using, modifying or 
 * distributing this software or its derivatives.
 *
 */

#ifndef __DRM_PR_MTP_H__
#define __DRM_PR_MTP_H__

#ifdef __cplusplus
extern "C" {
#endif

#include "drm-pr-mtp-types.h"

/*===========================================================================

						DRM PR-MTP service layer API

===========================================================================*/

/**
 * An application can Get PlayReady handle for MTP operations
 *
 * @param[in/out]  handlePr     Playready Handle for MTP operations
 * @return  		This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_init(DRM_PLAYREADY_MTP_HANDLE *handlePr);

/**
 * An application can Get Secure Time Challenge
 *
 * @param[in]  		handlePr     		Playready Handle for MTP operations
 * @param[out]  	pMtpData     		MTP Data
 * @param[out]  	plenMtpData     	MTP Data Length
 * @return  	This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_getsecuretimechallenge(DRM_PLAYREADY_MTP_HANDLE handlePr,
											   unsigned char **pMtpData,
											   unsigned int *plenMtpData);

/**
 * An application can Set Secure Time Response
 *
 * @param[in]  	handlePr     			Playready Handle for MTP operations
 * @param[in]  	pSecTimeResp     		pointer to the Secure Clock Response to be processed by the device
 * @param[in]  	lenSecTimeResp     		length of the Secure Clock Response
 * @param[out]  pdrResponse     		Contains the failure code if any while processing
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_setsecuretimeresponse(DRM_PLAYREADY_MTP_HANDLE handlePr,
											  unsigned char *pSecTimeResp,
											  unsigned int lenSecTimeResp,
											  long *pdrResponse);

/**
 * An application can Set Licence Response
 *
 * @param[in]  	handlePr     		Playready Handle for MTP operations
 * @param[in]  	pLicenseResp     	Licence Acquisition Response
 * @param[in]  	lenLicenseResp		Length of License Response
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure which has to be filled in the response parameter 1 in MTP Data
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_setlicenseresponse(DRM_PLAYREADY_MTP_HANDLE handlePr,
										  unsigned char *pLicenseResp,
										  unsigned int lenLicenseResp);

/**
 * An application can Get Sync List
 *
 * @param[in]  	handlePr     Playready Handle for MTP operations
 * @param[in]  	pRequest     Contains the Sync List Request parameters
 * @param[out]  pResponse    Contains the Sync List Response parameters
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_getsynclist(DRM_PLAYREADY_MTP_HANDLE handlePr,
								PR_SyncListRequestData *pRequest,
								PR_SyncListResponseData *pResponse);

/**
 * An application can send Meter Challenge Query
 *
 * @param[in]  pMeterChalQuery     		Contains the Meter Challenge Query
 * @param[in]  lenMeterChalQuery     	length of the Meter Challenge Query
 * @return  	This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_sendmeterchallengequery(unsigned char *pMeterChalQuery,
												 unsigned int lenMeterChalQuery);

/**
 * An application can Get Meter Challenge
 *
 * @param[in]  	handlePr     		Playready Handle for MTP operations
 * @param[out]	pMtpData			MTP Data
 * @param[out] 	plenMtpData			MTP Data Length
 * @return  	This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_getmeterchallenge(DRM_PLAYREADY_MTP_HANDLE handlePr,
										 unsigned char **pMtpData,
										 unsigned int *plenMtpData);

/**
 * An application can Set Meter Response
 *
 * @param[in]  	handlePr     				Playready Handle for MTP operations
 * @param[in]  	pMeterResp     				Contains the Metering Response
 * @param[in]  	lenMeterResp     			Length of the Metering Response
 * @param[out]  pMeterResponseFlags     	Meter Response Flags
 * @return  	This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_setmeterresponse(DRM_PLAYREADY_MTP_HANDLE handlePr,
										unsigned char *pMeterResp,
										unsigned int lenMeterResp,
										unsigned int *pMeterResponseFlags);

/**
 * An application can Clean Data Store on the device
 *
 * @param[in]  handlePr    		 Playready Handle for MTP operations
 * @param[in]  CleaningFlags     Currently undefined
 * @return  	This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_cleandatastore(DRM_PLAYREADY_MTP_HANDLE handlePr,
									 void *CleaningFlags);

/**
 * An application can Get Licence State
 *
 * @param[in]  	handlePr     		Playready Handle for MTP operations
 * @param[in]  	pStateQueryData     Contains StateQueryData
 * @param[in]  	lenStateQueryData   length of StateQueryData
 * @param[out]  pCategory     		Enum specifying the Licence Category State
 * @param[out]  ReservedData     	Currently Undefined
 */
long drm_pr_mtp_getlicensestate(DRM_PLAYREADY_MTP_HANDLE handlePr,
									 unsigned char *pStateQueryData,
									 unsigned int lenStateQueryData,
									 PR_DRM_LICENSE_STATE_CATEGORY *pCategory,
									 void *ReservedData);

/**
 * An application can send WMDRMPD Command to the device
 *
 * @param[in]  	handlePr     			Playready Handle for MTP operations
 * @param[in]  	pRequestArgument     	Contains Request Argument parameters
 * @param[in]  	pRequestData     		Contains data that is specific to the operation being requested
 * @param[in]  	lenRequestData     		length of data that is specific to the operation being requested
 * @param[out]  pResponseResult     	Contains Reponse Result parameters
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_sendwmdrmpdcommand(DRM_PLAYREADY_MTP_HANDLE handlePr,
												PR_WMDRMPDRequestData *pRequestArgument,
												unsigned char *pRequestData,
												unsigned int lenRequestData,
												PR_WMDRMPDResponseData *pResponseResult);

/**
 * An application can send WMDRMPD Request to the device
 *
 * @param[in]  	handlePr     		Playready Handle for MTP operations
 * @param[in]  	pRequestArgument    Contains Request Argument parameters
 * @param[out]  pMtpData     		MTP Data
 * @param[out]  plenMtpData     	MTP Data Length
 * @param[out]  pResponseResult     Contains Reponse Result parameters
 * @return  This function returns PR_MTP_SUCCESS on success or other values
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_sendwmdrmpdrequest(DRM_PLAYREADY_MTP_HANDLE handlePr,
											 PR_WMDRMPDRequestData *pRequestArgument,
											 unsigned char **pMtpData,
											 unsigned int *plenMtpData,
											 PR_WMDRMPDResponseData *pResponseResult);

/**
 * An application can send Join Domain Challenge Query
 *
 * @param[in]  pJoinDomainChalQuery     	Contains Join Domain Challenge Query
 * @param[in]  lenJoinDomainChalQuery    	length of Join Domain Challenge Query
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_sendjoindomainchallengequery(unsigned char *pJoinDomainChalQuery,
													   unsigned int lenJoinDomainChalQuery);

/**
 * An application can Get Join Domain Challenge
 *
 * @param[in]  		handlePr     		Playready Handle for MTP operations
 * @param[out]	 	pMtpData			MTP Data
 * @param[out] 	plenMtpData		 		MTP Data Length
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_getjoindomainchallenge(DRM_PLAYREADY_MTP_HANDLE handlePr,
											   unsigned char **pMtpData,
											   unsigned int *plenMtpData);

/**
 * An application can Set Join Domain Response
 *
 * @param[in]  handlePr     		Playready Handle for MTP operations
 * @param[in]  pJoinDomainResp     	Contains Join Domain Response
 * @param[in]  lenJoinDomainResp    length of Join Domain Response
 * @param[out] pdrResponse     		Contains the failure code if any while processing
 * @return  This function returns PR_MTP_SUCCESS on success or other values
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_setjoindomainresponse(DRM_PLAYREADY_MTP_HANDLE handlePr,
											  unsigned char *pJoinDomainResp,
											  unsigned int lenJoinDomainResp,
											  long *pdrResponse);

/**
 * An application can send Leave Domain Challenge Query
 *
 * @param[in]  pLeaveDomainChalQuery     	Contains Leave Domain Challenge Query
 * @param[in]  lenLeaveDomainChalQuery     	length of Leave Domain Challenge Query
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_sendleavedomainchallengequery(unsigned char *pLeaveDomainChalQuery,
														 unsigned int lenLeaveDomainChalQuery);

/**
 * An application can Get Leave Domain Challenge
 *
 * @param[in]  		handlePr     		Playready Handle for MTP operations
 * @param[out]  	pMtpData     		MTP Data
 * @param[out]  	plenMtpData     	MTP Data Length
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_getleavedomainchallenge(DRM_PLAYREADY_MTP_HANDLE handlePr,
												unsigned char **pMtpData,
												unsigned int *plenMtpData);

/**
 * An application can Set Leave Domain Response
 *
 * @param[in]  handlePr     		Playready Handle for MTP operations
 * @param[in]  pLeaveDomainResp     Contains Leave Domain Response
 * @param[in]  lenLeaveDomainResp   length of Leave Domain Response
 * @param[out] pdrResponse    	 	Contains the failure code if any while processing
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_setleavedomainresponse(DRM_PLAYREADY_MTP_HANDLE handlePr,
												unsigned char *pLeaveDomainResp,
												unsigned int lenLeaveDomainResp,
												long *pdrResponse);

/**
 * An application can Get Domain Certificate
 *
 * @param[in]  	handlePr    	 Playready Handle for MTP operations
 * @param[in]  	pRequestData     Contains Domain Certificate Request parameters
 * @param[out]  pMtpData     	 MTP Data
 * @param[out]  plenMtpData      MTP Data Length
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */
long drm_pr_mtp_getdomaincertificate(DRM_PLAYREADY_MTP_HANDLE handlePr,
									       PR_DomainCertRequestData *pRequestData,
									       unsigned char **pMtpData,
									       unsigned int *plenMtpData);

/**
 * An application can Get Device Property Description
 *
 * @param[in]  		handlePr     		Playready Handle for MTP operations
 * @param[in/out]  	pDevicePropDesc     Pointer to PR_DevicePropDesc
 * @return  This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see
 * @since          1.0
 */

long drm_pr_mtp_getdevicepropdesc(DRM_PLAYREADY_MTP_HANDLE handlePr,
										  PR_DevicePropDesc *pDevicePropDesc);

/**
 * An application can release PlayReady handle for MTP operations
 *
 * @param[in/out]  handlePr     Playready Handle for MTP operations
 * @return  		This function returns PR_MTP_SUCCESS on success or other values on failure
 * @remarks
 * @see 		drm_pr_mtp_init
 * @since          1.0
 */
long drm_pr_mtp_deinit(DRM_PLAYREADY_MTP_HANDLE *handlePr);

#ifdef __cplusplus
}
#endif
#endif/*__DRM_PR_MTP_H__*/
