/*
 *
 * Copyright (c) 2000 - 2012 Samsung Electronics Co., Ltd All Rights Reserved
 * This file is part of drm-service
 * Written by Hakjoo Ko <hakjoo.ko@samsung.com>
 * 
 * PROPRIETARY/CONFIDENTIAL
 *
 * This software is the confidential and proprietary information of
 * SAMSUNG ELECTRONICS ("Confidential Information"). You shall not 
 * disclose such Confidential Information and shall use it only in 
 * accordance with the terms of the license agreement you entered 
 * into with SAMSUNG ELECTRONICS.
 * SAMSUNG make no representations or warranties about the suitability
 * of the software, either express or implied, including but not limited
 * to the implied warranties of merchantability, fitness for a particular 
 * purpose, or non-infringement. SAMSUNG shall not be liable for any 
 * damages suffered by licensee as a result of using, modifying or 
 * distributing this software or its derivatives.
 *
 */

#ifndef __DRM_SERVICE_TYPES_H__
#define __DRM_SERVICE_TYPES_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <stddef.h>

/**
* PlayReady Server Error code
*/

			/* No server Error */
#define  	DRM_E_PR_SERVER_NONE 0x00000000

			/* Device Certificate is revoked.User shall be informed that their device needs to be updated.  */
#define 	DRM_E_PR_SERVER_DEVCERT_REVOKED	0x1004C065

			/* Indicates a server problem.Device shall silently retry 3 times.
			If failure persists, user shall be informed about a server failure and to try again later */
#define  	DRM_E_PR_SERVER_INTERNAL_ERROR 0x1004C600

			/* Means an invalid protocol message. This shall never happen unless there's been a "man in the middle" attack.
			Device shall perform a retry.*/
#define  	DRM_E_PR_SERVER_INVALID_MESSAGE 0x1004C601

			/* Means that the device limit has been reached for this domain and therefore the device cannot join this Domain.
			The application on the device shall provide the appropriate response to the end user. */
#define 	DRM_E_PR_SERVER_DEVICE_LIMIT_REACHED 0x1004C602

			/* Indicates that the device shall join a Domain and then retry license acquisition.*/
#define 	DRM_E_PR_SERVER_DOMAIN_REQUIRED 0x1004C605

			/* Indicates that the device shall renew the Domain Certificate for this Domain.
			The device shall join Domain and then retry license acquisition. */
#define 	DRM_E_PR_SERVER_RENEW_DOMAIN 0x1004C606

			/* Device shall leave Domain */
#define 	DRM_E_PR_SERVER_NOT_A_MEMBER 0x1004C60A

			/* Means that device is not using correct protocol, most likely because server has been updated since device was manufactured.
			The device shall notify user to check for updates or fail gracefully. */
#define 	DRM_E_PR_SERVER_PROTOCOL_VERSION_MISMATCH 0x1004C60B

			/* User shall always be authenticated before making license acquisitions.
			If this error happens, device shall notify user to contact customer service. */
#define 	DRM_E_PR_SERVER_UNKNOWN_ACCOUNTID 0x1004C60C

			/* Device shall follow redirect. */
#define 	DRM_E_PR_SERVER_PROTOCOL_REDIRECT 0x1004C60D

			/* Service specific Server errors */
#define 	DRM_E_PR_SERVER_SERVICE_SPECIFIC 0x1004C604

/* Maximum length of Content Url for Playredy contents */
#define DRM_PR_MAX_CONTENT_URL_LEN (511)


/* Notification type to indicate the application to take corresponding action accordingly */
typedef enum {
		/* License Acquisition notification type to indicate License Acquistion Operation */
/* 0 */	DRM_PR_OPN_NOTI_LICENSE_ACQ,

		/* Join Domain notification type to indicate Join Domain Operation */
/* 1 */	DRM_PR_OPN_NOTI_JOIN_DOMAIN,

		/* Leave Domain notificatin type to indicate Leave Domain Operation */
/* 2 */	DRM_PR_OPN_NOTI_LEAVE_DOMAIN,

		/* Metering notification type to indicate Metering Operation */
/* 3 */	DRM_PR_OPN_NOTI_METERING_INFO,

		/* Unknown notification type */
/* 4 */  DRM_PR_OPN_UNKNOWN_NOTI_TYPE

} DRM_PR_OPN_NOTITYPE;

/* PR operation status indicator */
typedef enum {
		/* To indicate to the application that the PR operation is In Progress */
/* 0 */	DRM_PR_OPN_INPROGRESS,

		/* To indicate to the application that PR operation is Completed */
/* 1 */	DRM_PR_OPN_COMPLETED,

		/* To indicate to the application that additional operation is to be performed */
/* 2 */  DRM_PR_OPN_ADDITIONAL_INFO,

		/* To indicate to the application that an error occured wrt to the PR operation */
/* 3 */  DRM_PR_OPN_ERROR

} DRM_PR_OPN_STATUS;

/* PlayReady COPY OPERATIONs based on destination type */
typedef enum {
	DRM_PR_COPY_UNKNOWN,	/**< For initialization purpose */
	DRM_PR_COPY_TO_DEV,		/**< copy to same device or another device */
	DRM_PR_COPY_TO_CD,		/**< copy / burn to CD / DVD */
	DRM_PR_COPY_TO_PC		/**< copy to PC */
} DRM_PR_COPY_OPERATION;

/* PlayReady COPY OPERATION status */
typedef enum {
	DRM_PR_COPY_SUCCESS, /**< To indicate Copy operation was successful */
	DRM_PR_COPY_FAILED	 /**< To indicate Copy operation failed */
} DRM_PR_COPY_STATUS;



/* Structure to hold the notification info required by the application */
typedef struct {
	DRM_PR_OPN_STATUS status;	/**< Status of PR operation */
	DRM_PR_OPN_NOTITYPE notitype;	/**< Type of PR operation */
} drm_pr_opn_noti_info;

/* Structure to hold the Operation Notify Callback parameters */
typedef struct {
	int result;			/**< Result returned from the Server */
	char *ServResp;			/**< Response from the Server */
	unsigned int ServRespLen;	/**< Server Response length */
} drm_pr_cb_param;

/* Function pointer for the CallBack function */
typedef void (*drm_pr_opn_notify_cb_t) (drm_pr_opn_noti_info *noti_info,
						drm_pr_cb_param *param);

typedef drm_pr_opn_notify_cb_t drm_pr_opn_notify_cb;

/* Added to incorporate future notifications if any */
typedef struct {
	drm_pr_opn_notify_cb DrmPrOpnNotifyCb;
} drm_pr_notify_t;

/* Playready response data filled during initiator processing.
This data will be useful for applications to take certain actions based on the server error codes
& to redirect to conten url page pointed by contentUrl if present,
CallBack function for processing application code based on the notification type */
typedef struct {
	char contentUrl[DRM_PR_MAX_CONTENT_URL_LEN + 1];    /**< Content Url */
	int DrmPrServerErrorCode;	      /**< Server Error Code */
	drm_pr_notify_t notify;		/**< CallBack Registration for Playready Notifications */
} drm_pr_response_data;

/* PlayReady Handle */
typedef void *DRM_PLAYREADY_APP_HANDLE;

/* PIFF specific datatypes */

/* PIFF Handle */
typedef void *DRM_PIFF_APP_HANDLE;

/* AES Operation Mode */
typedef enum {
	DRM_PIFF_UNKNOWN_CRYPTO,
	DRM_PIFF_AES_CBC,
	DRM_PIFF_AES_CTR
}DRM_PIFF_AES_MODE;

/*
* Structure for Holding PIFF Payload information
*/
typedef struct {
	unsigned char *payload_data; /**< PIFF Payload Data */
	unsigned int payload_data_len;	/**< PIFF Payload Data Length */
	unsigned char *payload_iv;	/**< PIFF Payload Initialization Vector for decryption */
	unsigned int payload_iv_len;	/**< PIFF Payload Initialization Vector length for decryption */
	unsigned int media_offset; /**< Byte offset in the media object this data payload belongs to */
	DRM_PIFF_AES_MODE aes_mode; /**< AES Operation Mode */
} drm_piff_payload_info;

/*
* Structure for Holding PIFF DRM License Header information
*/
typedef struct {
	unsigned char *header_buf; /**< PIFF DRM License Header buffer */
	unsigned int header_buf_len;	/**< PIFF DRM License Header buffer Length */
} drm_piff_header_info;


/**
* Definition Template
*/
#define DRM_HANDLE_NULL               0
/**
* Definition Template
*/
#define DRM_CEK_SIZE                  16
/**
* Definition Template
*/
#define DRM_DIGEST_SIZE               30
/**
* Definition Template
*/
#define DRM_RIGHTS_NAME_SIZE          64
/**
* Definition Template
*/
#define DRM_MAX_CID_LEN               255
/**
* Definition Template
*/
#define DRM_MAX_URL_LEN               255
/**
* Definition Template
*/
#define DRM_MAX_TYPE_LEN              64
/**
* Definition Template
*/
#define DRM_MAX_ASSET_COUNT           5

/**
* Definition Template
TransactionID char[16] :TransactionID of the DCF or PDCF respectively
*/
#define DRM_MAX_SIZE_TRANSACTION_ID		17

/**
* Definition Template
*/
#define 	DRM_CERT_PRODUCTION_PATH_NAME		"dummy"

/**
* Definition Template
*/
#define 	DRM_MAX_FILEPATH_LEN 	256

/**
* Typedef Definition Template
*/
typedef unsigned int DRM_CONTENTS_HANDLE;
/**
* Typedef Definition Template
*/
typedef unsigned int DRM_ASSET_HANDLE;
/**
* Typedef Definition Template
*/
typedef unsigned int DRM_RIGHTS_HANDLE;
/**
* Typedef Definition Template
*/
typedef void *DRM_DCF_HANDLE;
/**
* Typedef Definition Template
*/
typedef void *DRM_FILE_HANDLE;
/**
* Typedef Definition Template
*/
typedef void *DRM_PD_HANDLE;
/**
* Typedef Definition Template
*/
typedef void *DRM_CONVERT_HANDLE;
/**
* Typedef Definition Template
*/
typedef void *DRM_RIGHTS_LIST_HANDLE;

/**
* Enumeration Template
*/

typedef enum {
	DRM_FM_HOBJ_TYPE_NONE = 0x0000,
	DRM_FM_HOBJ_TYPE_FILE = 0x1000,
	DRM_FM_HOBJ_TYPE_DIR = 0x2000,
	DRM_FM_HOBJ_TYPE_DRM = 0x4000,
	DRM_FM_HOBJ_TYPE_NO_DRM_FILE = 0x8000
} DrmFmHObjType;

typedef struct {
	FILE *hFile;
	DrmFmHObjType objType;
} DRM_FILE_T;

typedef enum {
	DRM_FALSE = 0,			      /**<false*/
	DRM_TRUE = 1,			      /**<true */
	DRM_UNKNOWN = 0xFFFFFFFF	      /**<error */
} DRM_BOOL;

#define DRM_MAX_READ_SIZE 		(1024*1024)  /**< 1 Mbytes */

typedef enum {
	DRM_V1_KEY_TYPE_INVALID = -1,  /**<Invalid key */
	DRM_V1_KEY_TYPE_DUCK = 0,      /**<Use DUCK */
	DRM_V1_KEY_TYPE_MUCK = 1       /**<Use MUCK  */
} DRM_V1_KEY_TYPE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_RESULT_SUCCESS = 0,				     /**<success */
	/*All the failure cases will have a negative value */
	DRM_RESULT_INVALID_ARG = -1000,				 /**<invalid argument*/
	DRM_RESULT_PARSING_ERROR,			 /**<parsing contents or rights error*/
	DRM_RESULT_DB_ERROR,				 /**<data base error */
	DRM_RESULT_INSUFFICIENT_MEMORY,			 /**<memory error */
	DRM_RESULT_INTERNAL_ERROR,			 /**<process error */
	DRM_RESULT_FILE_ERROR,				 /**<file error */
	DRM_RESULT_RIGHTS_SLOT_FULL,			 /**<rights slot i full */
/* DRM_RESULT_DCF_HANDLE_ERROR = 100, */                  /**<contents parsing error */
	DRM_RESULT_VALID_NORIGHTS,			 /**<no rights exist*/
	DRM_RESULT_VALID_EXPIRE,			 /**<rights is expired*/
	DRM_RESULT_VALID_SUSPEND,			 /**<rights is suspended*/
	DRM_RESULT_NOT_IN_DOMAIN,			 /**<device is not in domain*/
	DRM_RESULT_FILE_UNLOCK_ERROR,			 /**<retrieving rights is fail */
	DRM_RESULT_SETAS_NOT_ALLOWED,			 /**<Content can not be set as */
	DRM_RESULT_SETAS_ALWAYS_ALLOWED,		    /**<Content can always be set as */
	DRM_RESULT_VALID_RIGHTS_LOCKED,				/**< Rights are locked  */
	DRM_RESULT_DCF_HASH_ERROR,
	DRM_RESULT_DIVX_NOT_AUTHORIZED,
	DRM_RESULT_DIVX_UNSUPPORT_DIVXDRM_VERSION,
	DRM_RESULT_PLUGIN_ERROR,
	DRM_RESULT_UNKNOWN_ERROR = -1		 /**<dummy error value */
} DRM_RESULT;

/**
* Enumeration Template
*/
typedef enum {
	DRM_USAGE_NONE = 0x00000000,
	DRM_USAGE_PLAY = 0x00000001,
	DRM_USAGE_DISPLAY = 0x00000002,
	DRM_USAGE_EXECUTE = 0x00000004,
	DRM_USAGE_PRINT = 0x00000008,
	DRM_USAGE_EXPORT = 0x00000010,
	DRM_USAGE_ANY = 0x0000001F,
	DRM_USAGE_UNKNOWN = 0xFFFFFFFF
} DRM_USAGE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_CONSTRAINT_UNPROTECTED = 0x00000000,
	DRM_CONSTRAINT_UNLIMITED = 0x00000001,
	DRM_CONSTRAINT_COUNT = 0x00000002,
	DRM_CONSTRAINT_TIMED_COUNT = 0x00000004,
	DRM_CONSTRAINT_DATETIME = 0x00000008,
	DRM_CONSTRAINT_INTERVAL = 0x00000010,
	DRM_CONSTRAINT_ACCUMULATED = 0x00000020,
	DRM_CONSTRAINT_INDIVIDUAL = 0x00000040,
	DRM_CONSTRAINT_SYSTEM = 0x00000080,
	DRM_CONSTRAINT_UNKNOWN = 0xFFFFFFFF
} DRM_CONSTRAINT_MASK;

/**
* Enumeration Template
*/
typedef enum {
	DRM_SORT_NONE,
	DRM_SORT_PRIORITY,
	DRM_SORT_RECEIVED_TIME,
	DRM_SORT_UNKNOWN = 0xFFFFFFFF
} DRM_SORT;

/**
* Enumeration Template
*/
typedef enum {
	DRM_STATUS_FAILED_NORMAL,
	DRM_STATUS_RI_CTXT_INVALID,
	DRM_STATUS_DOMAIN_CTXT_INVALID,
	DRM_STATUS_SECURE_CLK_LOST,
	DRM_STATUS_SUCCESS,
	DRM_STATUS_UNKNOWN = 0xFFFFFFFF
} DRM_RIGHTS_STATUS;

/**
* Enumeration Template
*/
typedef enum {
	DRM_RESET_ALL,
	DRM_RESET_INIT,
	DRM_RESET_REPLAY_CACHE,
	DRM_RESET_UNKNOWN = 0xFFFFFFFF
} DRM_RESET_OPTIONS;

/**
* Enumeration Template
*/
typedef enum {
	DRM_LOG,
	DRM_LOG_FILE,
	DRM_LOG_NET,
	DRM_LOG_RIGHTS,
	DRM_LOG_CONTENTS,
	DRM_LOG_INFO,
	DRM_LOG_WARNING,
	DRM_LOG_CLASS,
	DRM_LOG_ERROR
} DRM_LOG_FILTERS;

/**
* Enumeration Template
*/
/* Truncate Rights table */
typedef enum {
	DRM_REMOVEALL_RIGHTS_NONE,
	DRM_REMOVEALL_RIGHTS_BACKUP,
	DRM_REMOVEALL_RIGHTS_TRUNCATE,
	DRM_REMOVEALL_RIGHTS_RESTORE,
} DRM_REMOVEALL_RIGHTS_STATUS;

/**
* Enumeration Template
*/
/* File Open mode */
typedef enum {
	DRM_FILE_CREATE = 0x00000001,
	DRM_FILE_READ = 0x00000002,
	DRM_FILE_WRITE = 0x00000004,
	DRM_FILE_TRUNCATE = 0x00000008,
	DRM_FILE_APPEND = 0x00000010
} DRM_FILE_OPEN_MODE;

/**
* Enumeration Template
*/
/* File Seek mode */
typedef enum {
	DRM_SEEK_SET = 0,	     /**<begin position */
	DRM_SEEK_CUR,		     /**<current position */
	DRM_SEEK_END		     /**<end position */
} DRM_FILE_SEEK_MODE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_VALID_NORIGHTS = 0x00,    /**<no rights exist */
	DRM_VALID_EXPIRE = 0x01,	 /**<rights is expired */
	DRM_VALID_SUSPEND = 0x02,    /**<rights is suspended */
	DRM_VALID_VALID = 0x04,      /**<rights is valid*/
	DRM_VALID_MAX = 0xff	      /**<max */
} DRM_VALID_RESULT;

/**
* Enumeration Template
*/
typedef enum {
	DRM_EXPORT_NONE,	   /**<none */
	DRM_EXPORT_COPY,	   /**<export copy */
	DRM_EXPORT_MOVE,	   /**<export move */
	DRM_EXPORT_MAX = 0xff   /**<max */
} DRM_EXPORT_MODE;

/**************  R I G H T S ********************/
/**
*  Type Definition Template
*/
typedef struct {
	int year;			      /**<int */
	int month;			      /**<int */
	int day;			      /**<int */
	int hour;			      /**<int */
	int minute;			      /**<int */
	int second;			      /**<int */
} drm_time_t;

/**
*  Type Definition Template
*/
typedef struct {
	char *id;
	char *version;
} drm_system_t;

typedef enum {
	DRM_ERROR_FILE,
	DRM_ERROR_DB,
	DRM_CLIB_ERROR,
	DRM_ERROR_MEMORY,
	DRM_ERROR_SHARED_MEMORY
} DRM_LAST_ERROR_TYPE;

typedef struct {
	DRM_LAST_ERROR_TYPE errType;
	int errValue;
} drm_error_t;

/**
*  Type Definition Template
*/
typedef struct {
	char trID[DRM_MAX_SIZE_TRANSACTION_ID];		   /**transaction ID value*/
	unsigned char trIDLen;		     /**length of Transaction ID string. The value zero(0) indicates that transaction id is not available*/
} drm_transaction_id_info_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned int mask;			       /**<unsigned int */
	int totalCount;				       /**<int */
	int remainingCount;			       /**<int */
	int timedToatalCount;			       /**<int */
	int timedRemainingCount;		       /**<int */
	drm_time_t timedUnitTime;		       /**<drm_time_t */
	drm_time_t startTime;			       /**<drm_time_t */
	drm_time_t endTime;			       /**<drm_time_t */
	drm_time_t firstUsedTime;		       /**<drm_time_t */
	drm_time_t duration;			       /**<drm_time_t */
	drm_time_t totalTime;			       /**<drm_time_t */
	drm_time_t usedTime;			       /**<drm_time_t */
	DRM_EXPORT_MODE mode;			       /**<DRM_EXPORT_MODE */
	DRM_VALID_RESULT status;		       /**<DRM_VALID_RESULT */
} drm_constraint_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned char name[DRM_RIGHTS_NAME_SIZE + 1];
	unsigned int name_size;
	unsigned char contentId[DRM_MAX_CID_LEN + 1];
	unsigned int mask;

	drm_constraint_t conPlay;
	drm_constraint_t conDisplay;
	drm_constraint_t conExecute;
	drm_constraint_t conPrint;
	drm_constraint_t conExport;
} drm_rights_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned int mask;
	drm_constraint_t conPlay;
	drm_constraint_t conDisplay;
	drm_constraint_t conExecute;
	drm_constraint_t conPrint;
	drm_constraint_t conExport;
} drm_rights_permission_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_RIGHTS_STATUS result;
	DRM_VALID_RESULT status;
	DRM_ASSET_HANDLE asset_id;
	DRM_RIGHTS_HANDLE rights;
	drm_constraint_t constraint;
	DRM_BOOL isParentRO;
	unsigned int ri_ctxt;
	unsigned int do_ctxt;
	unsigned int do_generation;
	char ri_id[30];	/* fixed size (sha1 > base64) */
	char do_id[18];	/* fixed size */
	unsigned char cek[DRM_CEK_SIZE];
	char digest[DRM_DIGEST_SIZE];
	DRM_BOOL isGroupKey;
} drm_rights_result_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_RIGHTS_HANDLE rights;
	unsigned int riId;
	unsigned int doId;
	unsigned int version;
	DRM_BOOL bChild;
	unsigned char name[DRM_RIGHTS_NAME_SIZE + 1];
} drm_rights_list_result_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned int count;
	drm_rights_list_result_t *list;
} drm_rights_list_t;

/**
*  Type Definition Template
*/
typedef struct {
	char *riID;
	char *riAlias;
	char *riUrl;
	char *doID;
	char *doAlias;
	unsigned int generation;
} drm_context_info_t;

/**
*  Type Definition Template
*/
typedef struct _drm_rights_asset_details_t {
	char *cid;
	char *inherit;
	struct _drm_rights_asset_details_t *pNext;
} drm_rights_asset_details_t;

/**
*  Type Definition Template
*/
typedef struct _drm_rights_details_t {
	unsigned int version;
	drm_rights_asset_details_t asset;
	drm_rights_permission_t permission;
	struct _drm_rights_details_t *pNext;
} drm_rights_details_t;

/**
*  Type Definition Template
*/
typedef struct {
	char *roID;
	char *riURL;
	char *riID;
	drm_time_t *timeStamp;
	unsigned int version;
	DRM_BOOL statefulRO;
	DRM_BOOL domainRO;
} drm_ro_payload_details_t;

/**
*  Type Definition Template
*/
typedef struct {
	char *riID;
	char *riAlias;
	char *domainID;
	char *domainAlias;
	char *roDomainID;
} drm_rights_install_extension_t;

/**
*  Enumeration Template
*/
typedef enum {
	DRM_RIGHTS_INSTALL_SUCCESS,
	DRM_RIGHTS_INSTALL_GENERAL_ERROR,
	DRM_RIGHTS_INSTALL_NO_DEVICE_KEY,
	DRM_RIGHTS_INSTALL_MISSING_ELEMENT,
	DRM_RIGHTS_INSTALL_NO_RI_CONTEXT,
	DRM_RIGHTS_INSTALL_NO_DOMAIN_CONTEXT,
	DRM_RIGHTS_INSTALL_UNSUPPORTED_VERSION,
	DRM_RIGHTS_INSTALL_SIGNATURE_FAIL,
	DRM_RIGHTS_INSTALL_MAC_FAIL,
	DRM_RIGHTS_INSTALL_TIMESTAMP_REJECT,
	DRM_RIGHTS_INSTALL_REPLAYED,
	DRM_RIGHTS_INSTALL_RIGHTS_SLOT_FULL,
} DRM_RIGHTS_INSTALL_RESULT;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_RIGHTS_INSTALL_RESULT result;
	drm_rights_details_t *roInfo;
	drm_ro_payload_details_t *roPayload;
	drm_rights_install_extension_t *ext;
} drm_ro_install_result_t;

/**
* Enumeration Template
*/
typedef enum {
	DRM_OMA_DRMV1_RIGHTS,		   /**<OMA DRM v1 */
	DRM_OMA_DRMV2_RIGHTS,		   /**<OMA DRM v2 */
	DRM_WIDGET_RIGHTS,		/**<Widget DRM */
	DRM_UNDEFINED_RIGHTS		   /**<dummy */
} DRM_RIGHTS_VERSION;

/**
* Enumeration Template
*/
typedef enum {
	DRM_HANDLE_COUNT,
	DRM_HANDLE_TIME_BASED,
	DRM_HANDLE_TIMED_COUNT,	/*  for pause operation */
	DRM_HANDLE_STATELESS,
	DRM_HANDLE_UNKNOWN
} DRM_HANDLE_CONSTRAINT;

/**
* Enumeration Template
*/
typedef enum {
	DRM_HANDLE_ERROR = 0,
	DRM_HANDLE_NONE,
	DRM_HANDLE_STARTED,
	DRM_HANDLE_PAUSED,
	DRM_HANDLE_STOPPED
} DRM_HANDLE_STATUS;

/**
* Type Definition Template
*/
typedef struct {
	unsigned int m_asset_id;
	unsigned int m_group_id;
	unsigned int m_ro_id;
	DRM_USAGE m_permission;
	DRM_HANDLE_CONSTRAINT m_constraint;
	drm_time_t m_starttime;
	unsigned int m_elapsed;
	DRM_HANDLE_STATUS m_status;
} drm_handle_node_t;

/**
* Type Definition Template
*/
typedef struct {
	unsigned int version;

	char ri_ctxt_id[30];	/* fixed size */
	char ri_ctxt_url[101];	/* ri_url VARCHAR(100) */
	char ri_ctxt_alias[101];	/* ri_alias VARCHAR(100) */

	unsigned int do_no;	/* generation number */
	char do_ctxt_id[18];	/* fixed size */

	unsigned int timestamp;
	char ro_name[129];	/* name VARCHAR(128) */
	char cid[257];	/* c_id VARCHAR(256) UNIQUE */
	char guid[257];	/* guid VARCHAR(256) */

	DRM_BOOL b_parent;
	unsigned int pro_id;
	char pid[257];	/* guid VARCHAR(256) */

	drm_rights_t rights;
} drm_nth_result_t;

typedef enum {
	DRM_NTH_DIGEST_NONE,
	DRM_NTH_DIGEST_SHA1,
	DRM_NTH_DIGEST_MAX = 0xff
} DRM_NTH_DIGEST_METHOD;

typedef struct {
	DRM_BOOL b_haskeyinfo;
	char cid[257];
	char pid[257];

	DRM_BOOL b_hasdigestinfo;
	DRM_NTH_DIGEST_METHOD digest_method;
	char digest_value[21];	/* fixed size */
} DRM_NTH_ASSET;

/********************** R O A P **********************/
/**
* Enumeration Template
*/
typedef enum {
	DRM_ROAP_INIT_FROM_UNKNOWN,			    /**<dummy */
	DRM_ROAP_INIT_FROM_BROWSER,			    /**<roap is initialized from browser*/
	DRM_ROAP_INIT_FROM_DCF,			     /**<roap is initialized from dcf */
	DRM_ROAP_INIT_FROM_WAPPUSH		       /**<roap is initialized from WAPPUSH */
} DRM_ROAP_INITIATOR;

/**
* Type Definition Template
*/
typedef void (*drm_roap_service_cb_t) (void *cbParam,    /**<parameter */
					       void *appSessionData,   /**<application session data */
					       void *agentSessionData   /**<DRM agent session data */
	    );

/**
* Type Definition Template
*/
typedef drm_roap_service_cb_t drm_roap_notify_cb;
/**
* Type Definition Template
*/
typedef drm_roap_service_cb_t drm_roap_consent_cb;
/**
* Type Definition Template
*/
typedef drm_roap_service_cb_t drm_roap_result_cb;

/**
* Type Definition Template
*/
typedef struct {
	drm_roap_notify_cb progressNotify;				     /**<drm_roap_notify_cb*/
	drm_roap_consent_cb userConsent;				     /**<drm_roap_consent_cb*/
	drm_roap_result_cb roapResult;				     /**<drm_roap_result_cb*/
} drm_roap_notification_cb_t;

/* http related.*/
typedef enum {
	DRM_HTTP_METHOD_GET,
	DRM_HTTP_METHOD_POST
} DRM_ROAP_HTTP_REQUEST_METHOD;

/* MUST be match with EMRoapHttpResult */
typedef enum {
	DRM_ROAP_HTTP_RESULT_SUCCESS,
	DRM_ROAP_HTTP_RESULT_FAILED,
	DRM_ROAP_HTTP_RESULT_INVALID_RESPONSE,
	DRM_ROAP_HTTP_RESULT_TIME_OUT,
	DRM_ROAP_HTTP_RESULT_USER_CANCELED,
	DRM_ROAP_HTTP_RESULT_UNKNOWN
} DRM_ROAP_NETSVC_RESULT;

enum {
	DRM_ROAP_HTTP_STATUS_OK = 200
};

/**
* Enumeration Template
*/
/* user consent */
typedef enum {
	DRM_ROAP_USER_CONSENT_NONE,

	DRM_ROAP_USER_CONSENT_REGISTRATION,										/*MUST */
	DRM_ROAP_USER_CONSENT_JOINDOMAIN,										/* MAY */

	DRM_ROAP_USER_CONSENT_REGIST_OF_ROACQ,									/* MUST */
	DRM_ROAP_USER_CONSENT_REGIST_JOIN_OF_ROACQ,								/* MUST */
	DRM_ROAP_USER_CONSENT_REGIST_OF_JOIN,									/* MUST */
	DRM_ROAP_USER_CONSENT_REGIST_OF_LEAVE,									/* MUST */
	DRM_ROAP_USER_CONSENT_JOIN_OF_ROACQ,									/* MUST */

	DRM_ROAP_USER_CONSENT_LEAVE_FOR_UNKNWON_DOMAIN,							/* MUST */

	DRM_ROAP_USER_CONSENT_UNKNOWN
} DRM_ROAP_USER_CONSENT_TYPE;

/**
* Type Definition Template
*/
typedef struct _drm_roap_ro_acquisition_info_t {
	char *roID;
	char *roAlias;
	unsigned int countContentID;
	char **contentID;
	struct _drm_roap_ro_acquisition_info_t *pNext;
} drm_roap_ro_acquisition_info_t;

/**
* Type Definition Template
*/
typedef struct {
	char *riID;
	char *riAlias;
	char *domainID;
	char *domainAlias;
	char *roapURL;
	drm_roap_ro_acquisition_info_t *roAcq;
} drm_roap_protocol_session_t;

/**
* Type Definition Template
*/
typedef struct {
	DRM_ROAP_USER_CONSENT_TYPE consent;
	drm_roap_protocol_session_t *sessionInfo;
	char *domainIDofAgent;
} drm_roap_consent_cb_param_t;

/**
* Enumeration Template
*/
/* result related. */
typedef enum {
	DRM_ROAP_SUBMIT_RESULT_SUCCESS,
	DRM_ROAP_SUBMIT_RESULT_ERROR,
} DRM_ROAP_SUBMIT_RESULT_TYPE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_ROAP_SUBMIT_ERROR_NONE,
	DRM_ROAP_SUBMIT_ERROR_UNKNOWN,
	DRM_ROAP_SUBMIT_ERROR_OUTOFMEMORY,

	DRM_ROAP_SUBMIT_ERROR_USERCANCEL,

	DRM_ROAP_SUBMIT_ERROR_HTTP_RESULT,
	DRM_ROAP_SUBMIT_ERROR_HTTP_STATUS,
	DRM_ROAP_SUBMIT_ERROR_HTTP_CONTENT_TYPE,

	DRM_ROAP_SUBMIT_ERROR_PARSING,

	DRM_ROAP_SUBMIT_ERROR_RESPONSE_STATUS,
	DRM_ROAP_SUBMIT_ERROR_INVALID_SIGNATURE,

	DRM_ROAP_SUBMIT_ERROR_MISSING_ELEMENT,
	DRM_ROAP_SUBMIT_ERROR_MISSING_MAC_OF_LEAVEDOMAINTRIGGER,
	DRM_ROAP_SUBMIT_ERROR_MAC_INCONSISTENT_OF_TRIGGER,

	DRM_ROAP_SUBMIT_ERROR_NO_DEVICE_CERTIFICATE,

	DRM_ROAP_SUBMIT_ERROR_CHAIN_VALIDATION,

	DRM_ROAP_SUBMIT_ERROR_INVALID_RO,
	DRM_ROAP_SUBMIT_ERROR_RO_MAC_FAIL,
	DRM_ROAP_SUBMIT_ERROR_RO_SIGNATURE_FAIL,
	DRM_ROAP_SUBMIT_ERROR_RO_OLD_TIMESTAMP,
	DRM_ROAP_SUBMIT_ERROR_RO_UNAVAILABLE_TIMESTAMP,
	DRM_ROAP_SUBMIT_ERROR_RO_REPLAYED,
	DRM_ROAP_SUBMIT_ERROR_RO_STORAGE_FULL,
	DRM_ROAP_SUBMIT_ERROR_RO_INSTALLFAILED,

	DRM_ROAP_SUBMIT_ERROR_JOIN_FOR_OLD_GENERATION,
} DRM_ROAP_SUBMIT_ERROR_TYPE;

/**
* Enumeration Template
*/
/* must match with EMRoapMessageType */
typedef enum {
	DRM_ROAP_MESSAGE_UNKNOWN,
	DRM_ROAP_MESSAGE_TRIGGER,
	DRM_ROAP_MESSAGE_DEVICE_HELLO,
	DRM_ROAP_MESSAGE_RI_HELLO,
	DRM_ROAP_MESSAGE_REGISTRATION_REQUEST,
	DRM_ROAP_MESSAGE_REGISTRATION_RESPONSE,
	DRM_ROAP_MESSAGE_RO_REQEUST,
	DRM_ROAP_MESSAGE_RO_RESPONSE,
	DRM_ROAP_MESSAGE_JOINDOMAIN_REQUEST,
	DRM_ROAP_MESSAGE_JOINDOMAIN_RESPONSE,
	DRM_ROAP_MESSAGE_LEAVEDOMAIN_REQUEST,
	DRM_ROAP_MESSAGE_LEAVEDOMAIN_RESPONSE,
	DRM_ROAP_MESSAGE_PROTECTED_RO
} DRM_ROAP_PDU_TYPE;

/**
* Enumeration Template
*/
typedef struct {
	DRM_ROAP_SUBMIT_ERROR_TYPE errorType;
	DRM_ROAP_PDU_TYPE pduType;
	char *responseStatus;
	char *errorMessage;
	char *errorRedirectURL;
	unsigned int httpResult;
	unsigned int httpStatus;
	char *errorTitle;
	char *errorDescription;
	char *pNextUrl;
} drm_roap_submit_error_param_t;

/**
* Enumeration Template
*/
typedef enum {
	DRM_ROAP_UNKNOWN_TRIGGER,
	DRM_ROAP_REGISTRATION_TRIGGER,
	DRM_ROAP_ROACQUISITION_TRIGGER,
	DRM_ROAP_JOINDOMAIN_TRIGGER,
	DRM_ROAP_LEAVEDOMAIN_TRIGGER,
} DRM_ROAP_TRIGGER_TYPE;

/**
* Type Definition Template
*/
typedef struct {
	char *riID;
	char *deviceID;
	char *riURL;
	unsigned int roapVersion;
	char *expiryTime;
	char *riAlias;
	DRM_BOOL certificateCaching;
	char *ocspID;
	char *ocspNextUpdate;
} drm_roap_ri_context_t;

/**
* Type Definition Template
*/
typedef struct {
	char *domainID;
	char *expiryTime;
	char *domainAlias;
	DRM_BOOL hashChainSupport;
} drm_roap_domain_context_t;

/**
* Type Definition Template
*/
typedef struct _drm_roap_transaction_info_t {
	char *contentID;
	char *oldTrID;
	char *newTrID;
	struct _drm_roap_transaction_info_t *pNext;
} drm_roap_transaction_info_t;

/**
* Type Definition Template
*/
typedef struct {
	drm_roap_transaction_info_t *transaction;
	unsigned int dnwlCount;
	char **domainNameWhiteList;
} drm_roap_result_extension_t;

/**
* Type Definition Template
*/
typedef struct {
	int dummy;
} drm_roap_ro_install_result_t;

/**
* Type Definition Template
*/
typedef struct _drm_roap_protected_ro_info_t {
	/* PAYLOAD INFO */
	char *roID;
	char *riURL;
	char *riID;
	char *timeStamp;
	unsigned int version;
	DRM_BOOL statefulRO;
	DRM_BOOL domainRO;
	/* RIGHTS
	     REL 2.0 ... */
	unsigned int cidCount;
	char **cid;

	drm_roap_ro_install_result_t *roResult;
	struct _drm_roap_protected_ro_info_t *pNext;
} drm_roap_protected_ro_info_t;

/**
* Type Definition Template
*/
typedef struct {
	DRM_ROAP_INITIATOR sessionInitiator;
	DRM_ROAP_TRIGGER_TYPE trigger;
	drm_roap_protocol_session_t *sessionInfo;
	drm_roap_ri_context_t *riInfo;
	drm_roap_domain_context_t *domainInfo;
	drm_roap_protected_ro_info_t *roInfo;
	drm_roap_result_extension_t *extension;
} drm_roap_submit_session_param_t;

/**
* Type Definition Template
*/
typedef struct {
	DRM_ROAP_SUBMIT_RESULT_TYPE result;
	drm_roap_submit_session_param_t *session;
	drm_roap_submit_error_param_t *errorInfo;
} drm_roap_result_cb_param_t;

/**
* Type Definition Template
*/
typedef enum {
	DRM_ROAP_PROTOCOL_UNKNOWN,
	DRM_ROAP_PROTOCOL_REGISTRATION,
	DRM_ROAP_PROTOCOL_RO_ACQUISITION,
	DRM_ROAP_PROTOCOL_JOIN_DOMAIN,
	DRM_ROAP_PROTOCOL_LEAVE_DOMAIN
} DRM_ROAP_PROTOCOL_TYPE;

/**
* Type Definition Template
*/
typedef enum {
	DRM_ROAPPDU_STATE_UNKNOWN,
	DRM_ROAPPDU_STATE_PARSING,
	DRM_ROAPPDU_STATE_VALIDATING,
	DRM_ROAPPDU_STATE_PROCESSING,
	DRM_ROAPPDU_STATE_COMPOSING,
	DRM_ROAPPDU_STATE_GENERATING,
	DRM_ROAPPDU_STATE_NETWORKSENDING,
	DRM_ROAPPDU_STATE_NETWORKWAITING,
	DRM_ROAPPDU_STATE_CONSENTREQEUSTING,
	DRM_ROAPPDU_STATE_CONSENTWAITING,
	DRM_ROAPPDU_STATE_COMPLETE
} DRM_ROAP_PROTOCOL_STATUS;

/**
* Type Definition Template
*/
/* Notification for roap status */
typedef struct {
	DRM_ROAP_PROTOCOL_TYPE protocolType;
	DRM_ROAP_PDU_TYPE pduType;
	DRM_ROAP_PROTOCOL_STATUS statusType;
} drm_roap_notify_cb_param_t;

/*********************** D C F ************************/
/**
* Enumeration Template
*/
typedef enum {
	DRM_ENC_PLAIN = 0x00,		      /**<plaintext */
	DRM_ENC_AES_CBC = 0x01,		      /**<AES_CBC */
	DRM_ENC_AES_CTR = 0x02,		      /**<AES_CTR */
	DRM_ENC_UNKNOWN = 0xFFFFFFFF	      /**<dummy value*/
} DRM_ENC_METHOD;

/**
* Enumeration Template
*/
typedef enum {
	DRM_PAD_NONE = 0x00,		      /**<no padding*/
	DRM_PAD_RFC2630 = 0x01		      /**<RFC-2630*/
} DRM_PADDING_SCHEME;

/**
* Enumeration Template
*/
typedef enum {
	DRM_ENCODING_NONE,		   /**<none */
	DRM_ENCODING_7BIT,		   /**<7bit */
	DRM_ENCODING_8BIT,		   /**<8bit */
	DRM_ENCODING_BINARY,		   /**<binary */
	DRM_ENCODING_BASE64,		   /**<base64 */
	DRM_ENCODING_QPRINT		   /**<qprint */
} DRM_ENCODING_TYPE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_ROURL_METHOD_ROPAYLOAD,	/*Embedded Domain/Device RO in DCF */
	DRM_ROURL_METHOD_SILENT,	/*Silent in advance or silent on demand */
	/*DRM_ROURL_METHOD_PREVIEW,   Preview URI */
	DRM_ROURL_MAX		/**<max value */
} DCF_EMBEDDED_ROURL_TYPE;

/**
* Enumeration Template
*/
/**
* Enumeration Template
*/
typedef enum {
	/* textual headers */
	/* silent_preview / preview / contentURL / versionID / contentLocation / extended... */
	DRM_TEXTHEADER_PRIORITY_SILENT_IN_ADVANCE, /**<silent:in-advance */
	DRM_TEXTHEADER_PRIORITY_SILENT_ON_DEMAND, /**<silent:on-demand */
	DRM_TEXTHEADER_PRIORITY_PREVIEW_INSTANT,/**<preview:instant */
	DRM_TEXTHEADER_PRIORITY_PREVIEW_RIGHTS,/**<preview:preview-rights */
	DRM_TEXTHEADER_PRIORITY_CONTENT_URL,	/**<content URL */
	DRM_TEXTHEADER_PRIORITY_VERSIONID,		/**<version ID */
	DRM_TEXTHEADER_PRIORITY_CONTENT_LOCATION,	/**<content location */
	DRM_TEXTHEADER_PRIORITY_CUSTOM,	/**<extended */
	DRM_TEXTHEADER_PRIORITY_RO_PAYLOAD_URL,	/*ROPayload embedded inside DCF */
	/* end */
	DRM_TEXTHEADER_PRIORITY_MAX	/**<max */
} DRM_TEXTHEADER_PRIORITY_TYPE;

typedef enum {
	/* textual headers */
	/* silent_preview / preview / contentURL / versionID / contentLocation / extended... */
	DRM_TEXTHEADER_SILENT, /**<silent */
	DRM_TEXTHEADER_PREVIEW,/**<preview */
	DRM_TEXTHEADER_CONTENT_URL,			       /**<content URL */
	DRM_TEXTHEADER_VERSIONID,			       /**<version ID */
	DRM_TEXTHEADER_CONTENT_LOCATION,			       /**<content location */
	DRM_TEXTHEADER_CUSTOM, /**<extended */
	/* end */
	DRM_TEXTHEADER_MAX     /**<max */
} DRM_TEXTHEADER_TYPE;

typedef enum {
	DRM_METHOD_NONE = 0,
	DRM_METHOD_SILENT_INADVANCE,
	DRM_METHOD_SILENT_ONDEMAND,
	DRM_METHOD_PREVIEW_INSTANT,
	DRM_METHOD_PREVIEW_RIGHTS
} DRM_HEADER_METHOD;

/**
* Enumeration Template
*/
typedef enum {
	/* user data box */
	/* title / Description / Copyright / Author / IconURI / InfoURL / extended... */
	DRM_USERDATA_TITLE,    /**<title */
	DRM_USERDATA_DESCRIPTION,       /**<description */
	DRM_USERDATA_COPYRIGHT,/**<copyright */
	DRM_USERDATA_AUTHOR,   /**<author */
	DRM_USERDATA_ICON_URI, /**<icon URI */
	DRM_USERDATA_INFO_URL, /**<info URL */

	/* end */
	DRM_USERDATA_MAX       /**<max value */
} DRM_USERDATA_TYPE;

/**
* Type Definition Template
*/
typedef struct {
	char *p;		  /**<char * */
	unsigned int len;	  /**<unsigned int */
} drm_dcf_token_t;

/**
* Type Definition Template
*/
typedef struct st_drm_dcf_text_header_t {
	DRM_TEXTHEADER_TYPE type;    /**<DRM_TEXTHEADER_TYPE */
	drm_dcf_token_t name;	     /**<drm_dcf_token_t */
	drm_dcf_token_t value;	     /**<drm_dcf_token_t */
	drm_dcf_token_t value2;	     /**<drm_dcf_token_t */
	struct st_drm_dcf_text_header_t *next;	/*st_drm_dcf_text_header_t */
} drm_dcf_text_header_t;

/**
* Type Definition Template
*/
typedef struct {
	/* Common info */
	char *contentType;				     /**<char * */
	DRM_ENC_METHOD encMethod;			     /**<DRM_ENC_METHOD */
	DRM_PADDING_SCHEME paddingScheme;		     /**<DRM_PADDING_SCHEME */
	unsigned int plaintextLen;			     /**<unsigned int*/
	char *contentID;				     /**<char * */
	char *rightsIssuerURL;				     /**<char * */
	/* Texual Header */
	/* silent_preview / preview / contentURL / versionID / contentLocation / extended... */
	drm_dcf_text_header_t *headers[DRM_TEXTHEADER_MAX];  /**<drm_dcf_text_header_t **/
	drm_dcf_text_header_t *customHeaders;		     /**<drm_dcf_text_header_t **/
	/* DRM_TEXTHEADER_TYPE               previewPriority; */                /**<DRM_TEXTHEADER_TYPE */
	DRM_TEXTHEADER_PRIORITY_TYPE previewPriority;	/**<DRM_TEXTHEADER_PRIORITY_TYPE */
	/* User Data */
	/* title / Description / Copyright / Author / IconURI / InfoURL / extended... */
	char *userData[DRM_USERDATA_MAX];		     /**<char * */

	unsigned int contentOffset;			     /**<unsigned int */
	unsigned int contentLength;			     /**<unsigned int */

	DRM_ENC_METHOD gkEncMethod;			     /**<DRM_ENC_METHOD */
	char *groupID;					     /**<char * */
	unsigned char *groupKey;			     /**<unsigned char **/
	unsigned int gkLen;				     /**<unsigned int */

	DRM_ENCODING_TYPE transferEncoding;		     /**<DRM_ENCODING_TYPE */
} drm_dcf_desc_t;

/**
* Type Definition Template
*/
typedef struct {
	DRM_CONTENTS_HANDLE contents;
	unsigned int assetCount;
} drm_install_result_t;

/**
* Type Definition Template
*/
typedef struct {
	DRM_CONTENTS_HANDLE contents;
	char *path;
	unsigned int index;
	unsigned int offset;
	unsigned int size;
} drm_dcf_file_info_t;

/**
* Type Definition Template
*/
typedef struct {
	unsigned int count;
	drm_dcf_file_info_t *list;
} drm_dcf_file_info_list_t;

/**
* Enumeration Template
*/
typedef enum {
	DRM_TS_USER,	 /**<Time source = user, it is NOT a secure time source */
	DRM_TS_NITZ,	 /**<Time source = NITZ (Network Identity and Time Zone), it is a secure time source */
	DRM_TS_OCSP,	 /**<Time source = OCSP (Online Certificate Status Protocol for OMA DRM), it is a secure time source */
	DRM_TS_DEFAULT_OCSP,
	DRM_TS_MS_TTS,	 /**<Time source = MS TTS (Microsoft Trusted Time Source for PlayReady), it is a secure time source*/
	DRM_TS_MAX
} DRM_EM_TIME_SOURCE;

/**
* Definition Template
*/
#define DRM_UDTA_STR_MAX_LEN 255

/**
* Type Definition Template
*/
typedef struct {
	char str[DRM_UDTA_STR_MAX_LEN + 1];	 /**<char []*/
} drm_u_string_t;

/**
* Type Definition Template
*/
typedef struct {
	char str[DRM_UDTA_STR_MAX_LEN + 1];       /**<char [] */
	char lang[4];	       /**<char [] */
} drm_ud_string_t;

/**
* Type Definition Template
*/
typedef struct {
	char lang[4];
	char str[DRM_UDTA_STR_MAX_LEN + 1];
	unsigned int entity;
	unsigned int criteria;
} drm_ud_rating_t;

/**
* Type Definition Template
*/
typedef struct {
	char lang[4];	       /**<char [] */
	char str[DRM_UDTA_STR_MAX_LEN + 1];		       /**<char [] */
	unsigned int entity;   /**<unsigned int */
	unsigned int table;  /**<unsigned shart */
} drm_ud_classification_t;

/**
* Type Definition Template
*/
typedef struct {
	char lang[4];	    /**<char [] */
	unsigned char keywordsCnt;			    /**<unsigned char* */
	drm_u_string_t *keyword;			    /**<drm_u_string_t */
} drm_ud_keywords_t;

/**
* Type Definition Template
*/
typedef struct {
	char lang[4];			   /**<char []*/
	char name[DRM_UDTA_STR_MAX_LEN + 1];		   /**<char []*/
	unsigned char role;		   /**<unsigned char*/
	unsigned int longitude;		   /**<unsigned int*/
	unsigned int latitude;		   /**<unsigned int*/
	unsigned int altitude;		   /**<unsigned int*/
	char body[DRM_UDTA_STR_MAX_LEN + 1];	   /**<char []*/
	char note[DRM_UDTA_STR_MAX_LEN + 1];	   /**<char []*/
} drm_ud_location_info_t;

/**
* Type Definition Template
*/
typedef struct {
	char lang[4];				 /**<char []*/
	char albumTitle[DRM_UDTA_STR_MAX_LEN + 1];		 /**<char []*/
	unsigned char trackNum;		 /**<unsigned char */
} drm_ud_album_t;

/**
* Type Definition Template
*/
typedef struct {
	unsigned short recodingYear; /**<unsigned short */
} drm_ud_recoding_year_t;

/**
* Type Definition Template
*/
typedef struct {
	unsigned int len;/**<unsigned int */
	unsigned char *pData; /**<unsigned char * */
} drm_ud_other_t;

/**
* Type Definition Template
*/
typedef struct {
	unsigned int index;		      /**unsigned int */
	unsigned int boxType;		      /**<unsigned int */
	union {
		drm_ud_string_t title;	      /**<drm_ud_string_t */
		drm_ud_string_t desc;	      /**<drm_ud_string_t */
		drm_ud_string_t copyright;    /**<drm_ud_string_t */
		drm_ud_string_t author;	      /**<drm_ud_string_t */
		drm_ud_string_t performer;    /**<drm_ud_string_t */
		drm_ud_string_t genre;	      /**<drm_ud_string_t */
		drm_ud_string_t iconURI;      /**<drm_ud_string_t */
		drm_ud_string_t infoURL;      /**<drm_ud_string_t */
		drm_ud_string_t coverURI;     /**<drm_ud_string_t */
		drm_ud_string_t lyrics;	      /**<drm_ud_string_t */
		drm_ud_rating_t rating;	      /**<drm_ud_string_t */
		drm_ud_classification_t classification;	      /**<drm_ud_classification_t */
		drm_ud_keywords_t keywords;   /**<drm_ud_keywords_t */
		drm_ud_location_info_t location;					      /**<drm_ud_location_info_t */
		drm_ud_album_t album;	      /**<drm_ud_album_t */
		drm_ud_recoding_year_t recodingYear;		      /**<drm_ud_recoding_year_t */
		drm_ud_other_t others;	      /**<drm_ud_other_t */
	} subBox;
} drm_user_data_common_t;

/**
* Type Definition Template
*/
typedef struct {
	unsigned int *asset_id;
	unsigned int *group_id;
	unsigned int *content_size;
	unsigned int count;
} drm_contents_t;

/**
* Enumeration Template
*/
/* Progressive Download */
typedef enum {
	DRM_PD_WAIT,	/* 0 Chunk Data */
	DRM_PD_PARSE,	/* 1 Header Parsing */
	DRM_PD_UNLOCK,	/* 2 Unlock */
	DRM_PD_NEED_KEY,	/* 3 Key */
	DRM_PD_DECRYPT,	/* 4 Content */
	DRM_PD_SKIP,	/* 5 Content */
	DRM_PD_EOF	/* 6 End of File */
} DRM_PD_STATUS;

/**
* Type Definition Template
*/
typedef struct {
	DRM_PD_STATUS status;

	/* content info */
	int index;	/* container index */
	char contentType[DRM_MAX_TYPE_LEN + 1];
	unsigned int plaintextLen;
} drm_pd_output_t;

/**
* Type Definition Template
*/
/* Non-streamable PDCF structures */
typedef struct {
	DRM_ENC_METHOD gkEncMethod;
	char *groupID;
	unsigned char *groupKey;
	unsigned int gkLen;
} drm_group_id_t;

/**
* Type Definition Template
*/
typedef struct {
	DRM_ENC_METHOD encMethod;
	DRM_PADDING_SCHEME paddingScheme;
	unsigned int plaintextLen;
	char *contentID;
	char *rightsIssuerURL;
	drm_dcf_text_header_t *txtHeaders;
	drm_group_id_t *groupIDBox;
} drm_common_headers_t;

/**
* Type Definition Template
*/
typedef struct {
	DRM_BOOL selectiveEncryption;
	unsigned char keyIndicatorLength;
	unsigned char IVLength;
} drm_au_format_box_t;

/**
* Type Definition Template
*/
typedef struct {
	drm_common_headers_t headers;
	drm_au_format_box_t AUFormat;
} drm_kms_box_t;

/**
* Type Definition Template
*/
typedef struct st_drm_user_consent_white_list_t {
	char *url;
	struct st_drm_user_consent_white_list_t *next;
} drm_user_consent_white_list_t;

/**
* Type Definition Template
*/
/*User info: user consent and user feedback*/
typedef struct drm_uc_info_t {
	DRM_BOOL bConsent;
	DRM_BOOL bAddToTrustedWhiteList;
} drm_uc_info_t;

typedef DRM_BOOL (*DrmAppCallback) (void *data);

typedef enum {
	DRM_EVENT_DBUS_MODE,
	DRM_EVENT_EDBUS_MODE,
	DRM_EVENT_MODE_NONE
} DRM_EVENT_MODE;

typedef struct {
	unsigned int roid;
	char cid[256];
} drm_run_event_info;

typedef struct {
	DRM_EVENT_MODE mode;	/* Event mode type  */
	DrmAppCallback callback;
	void *data;	/*for future usage */
	const char *event;	/*Event String */
	unsigned int subscription_id;
} drm_event_subscribe_info;

/**
* Typedef Definition Template
*/
typedef void *DRM_RIGHTS_CONSUME_HANDLE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_FILE_TYPE_OMA,		/**<OMA drm file type */
	DRM_FILE_TYPE_DIVX,		/**<DivXDRM file type */
	DRM_FILE_TYPE_PLAYREADY,/**<Playready file type*/
	DRM_FILE_TYPE_SAPPS,	/**<Playready file type*/
	DRM_FILE_TYPE_NONE		/**<Unknown file type */
} DRM_FILE_TYPE;

#define MT_MAX_REGI_CODE_SIZE 10
#define MT_MAX_DEREGI_CODE_SIZE 8
#define M_MAX_REGI_CODE_SIZE 8

/**
*  Type Definition Template
*/
typedef struct {
	DRM_FILE_TYPE drmType;		  /**<drm type of handle */
	union {
		DRM_RIGHTS_CONSUME_HANDLE omaHandle;	/**<DRM_RIGHTS_CONSUME_HANDLE */
		char *wmdrmFilePath;				/**<char* */

	};
} common_drm_rights_handle_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_FILE_TYPE drmType;	  /**<drm type of handle */
	union {
		DRM_FILE_HANDLE omaHandle;		   /**<DRM_FILE_HANDLE */
		void *divxdrmHandle;	       /**<divxdrmHandle */
	};
} common_drm_file_handle_t;

/**
*  Type Definition Template
*/
typedef struct _drm_file_handle_t {
	DRM_FILE_HANDLE hFile;
	int fd;
	struct _drm_file_handle_t *pNext;
} drm_file_handle_t;

/*===========================================================================

								DEFINITIONS AND DECLARATIONS

===========================================================================*/

/**
* Definition Template
*/
#define DRM_MAX_RIID_LEN  (256+1)
/**
* Definition Template
*/
#define DRM_MAX_RIURL_LEN  (1024+1)
/**
* Definition Template
*/
#define DRM_MAX_ROALIAS_LEN  (256+1)
/**
* Definition Template
*/
#define DRM_MAX_ROID_LEN  (256+1)
/**
* Definition Template
*/
#define DRM_MAX_PID_LEN  (256+1)

/**
* Definition Template
*/
#define DRM_MAX_DOMAIN_ID_SIZE  17

/**
* Definition Template
*/
#define DRM_MAX_PERMISSION_COUNT  5
/**
* Definition Template
*/
#define DRM_CEK_SIZE  16
/**
* Definition Template
*/
#define DRM_DIGEST_SIZE  30
/**
* Definition Template
*/
#define DRM_MAX_FILEPATH_COUNT 1000
/**
* Definition Template
*/
/* #define DRM_MAX_FILEPATH_LEN 256 */
/**
* Definition Template
*/
#define DRM_MAX_CONTENT_NAME_LEN  1024
/**
* Definition Template
*/
#define DRM_MAX_CONTENT_DESCRIPTION_LEN  1024
/**
* Definition Template
*/
#define DRM_MAX_VENDOR_LEN  1024
/**
* Definition Template
*/
#define DRM_MAX_ICON_URI_LEN  1024
/**
* Definition Template
*/
#define DRM_MAX_TITLE_LEN  1024
/**
* Definition Template
*/
#define DRM_MAX_COPYRIGHT_LEN  1024
/**
* Definition Template
*/
#define DRM_MAX_AUTHOR_LEN  1024
/**
* Definition Template
*/
#define DRM_MAX_INFO_URL_LEN  1024

#define DRM_MAX_USER_DATA 1024

/**
* Definition Template
*/
#define DRM_MAX_IP_ADDR 63

/**
* Definition Template
*/
#define DRM_MAX_FILE_HANDLE   256

/*
PlayReady Specific MIME Types
*/

/**< PlayReady audio file MIME TYPE */
#define DRM_PLAYREADY_MIME_TYPE_AUDIO			"audio/vnd.ms-playready.media.pya"

/**< PlayReady video file MIME TYPE */
#define DRM_PLAYREADY_MIME_TYPE_VIDEO			"video/vnd.ms-playready.media.pyv"

/**< This MIME type indicates the payload is a PLAYREADY V2 DRM content header */
#define DRM_PLAYREADY_MIME_TYPE_LIC_CHLG_REQ	"application/vnd.ms-wmdrm.lic-chlg-req"

/**< This MIME type is used for PLAYREADY V2 messages from the server that contain the license responses */
#define DRM_PLAYREADY_MIME_TYPE_LIC_RESP		"application/vnd.ms-wmdrm.lic-resp"

/**< This MIME type is used for PLAYREADY V2 messages from the server that contain the metering certificate */
#define DRM_PLAYREADY_MIME_TYPE_METER_CHLG_REQ	"application/vnd.ms-wmdrm.meter-chlg-req"

/**< This MIME type indicates the payload is a V4 initiator that can contain data
to initiate license acquisition, a metering ID (to initiate metering), a join domain initiator or a leave domain initiator.
The actual content of the initiator has to be determined by the helper application by means of parsing it with an XML parser */
#define DRM_PLAYREADY_MIME_TYPE_INITIATOR		"application/vnd.ms-playready.initiator+xml"

/**
* Definition Template
*/

#define 	DRM_DBUS_SELF_SERVICE_NAME 		""

/**
* Definition Template
*/
#define DRM_NOTI_ID_RO_CONSUMED 			"SecurityFramework.DrmService.ROConsumed"

/**
* Definition Template
*/
#define DRM_NOTI_ID_RO_EXPIRED    			"SecurityFramework.DrmService.ROExpired"

/**
* Definition Template
*/
#define DRM_NOTI_ID_RO_ACTIVATED			"SecurityFramework.DrmService.ROActivated"

/**
* Definition Template
*/
#define DRM_NOTI_ID_UPDATE_RUN_ALARM	"SecurityFramework.DrmService.UpdateDrmAlarm"

/**
* Definition Template
*/
#define DRM_NOTI_ID_CMLA_RECEIVED 			"Telephony.IMEI.CMLAIND"

/**
* Definition Template
*/
#define DRM_NOTI_ID_CMLA_COMPARE 			"Telephony.IMEI.CompareItem"

/**
* System Constraint related Structures:start
*/

#define DRM_MAX_SIZE_IMSI_STR 		32

#define DRM_MAX_MIME_LEN  			32
typedef struct {
	char szVal[DRM_MAX_SIZE_IMSI_STR];	/**< IMSI Value */
} imsi_info_t;

typedef enum {
/*  0  */	E_DRM_NOTI_ID_UPDATE_RUN_ALARM,		/**< Event for Update DRM RUn ALARM */
/*  1  */	E_DRM_NOTI_ID_RO_EXPIRED,  				/**< Event of RO expired */
/*  3  */	E_DRM_NOTI_ID_RO_ACTIVATED,				/**< Event of RO Activated */
/*  4  */	E_DRM_NOTI_ID_CMLA_RECEIVED,				/**< Event of CMLA Received */
/*  5  */	E_DRM_NOTI_ID_CMLA_COMPARE,				/**< Event of CMLA Compare */
/*  6  */	E_DRM_NOTI_ID_NOT_VALID	 				/**< INVALID Event */
} DRM_NOTI_TYPE;

typedef enum {
/* 0 */ DRM_ALARM_TYPE_RUN, /**< Alarm type for RUN */
/* 1 */ DRM_ALARM_TYPE_EXPIRY_REMNIDER, /**< Alarm type for Expiry Reminder */
/* 2 */ DRM_ALARM_TYPE_MAX /**< Invalid Alarm type */
} DRM_ALARM_TYPE;

typedef enum {
/*  0  */	DRM_APP_TYPE_GROUP_MEDIA_PLAYER,									/**< Set by Media player */
/*  1  */	DRM_APP_TYPE_GROUP_AUTOMATED_CONSUME,  							/**< Set by Settings Application */
/*  2  */	DRM_APP_TYPE_DUAL_GROUP_MEDIA_PLAYER__AUTOMATED_CONSUME,		/**< Set by Browser */
} DRM_APPLICATION_INFO;

typedef struct {
	DRM_APPLICATION_INFO val;				/**< Application information */
} app_type_info_t;

typedef enum {
/*  0  */	  DRM_SYS_CONSTRAINT_IMSI_TYPE,		/**< Constraint type is IMSI */
/*  1  */	  DRM_SYS_CONSTRAINT_APP_TYPE		/**< Constraint type is Application data */
} DRM_APP_SYS_CONSTRAINT_TYPE;

typedef struct {
	DRM_APP_SYS_CONSTRAINT_TYPE type;		/**< Constraint type  */
	union {
		imsi_info_t imsi;					/**< IMSI Value  */
		app_type_info_t app_type;			/**< Application type  */
	} constraint_info;
} drm_app_constraint_info;

/**
* System Constraint related Structures:End
*/

typedef enum {
/* -1 */ DRM_USE_FLAG_NONE = -1,
/* 0 */ DRM_USE_FLAG_PSH_WALLPAPER = 0,
/* 1 */ DRM_USE_FLAG_PSH_COVERLCD,
/* 2 */ DRM_USE_FLAG_PSH_RINGTONE,
/* 3 */ DRM_USE_FLAG_CT_USER_IMAGE,
/* 4 */ DRM_USE_FLAG_CT_USER_RINGTONE,
/* 5 */ DRM_USE_FLAG_CT_USER_MSGTONE,
/* 6 */ DRM_USE_FLAG_ORG_ALARM
} DRM_SETAS_CATEGORY;

typedef enum {
	DRM_DB_EXPIRY_NONE = -1,
	DRM_DB_EXPIRY_0H = 0,
	DRM_DB_EXPIRY_24H,
	DRM_DB_EXPIRY_48H
} DRM_DB_EXPIRY_TYPE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_EVENT_RO_CONSUMED,			 /**<title */
	DRM_EVENT_RO_EXPIRED,			 /**<title */
	DRM_EVENT_RO_ACTIVATED,		     /**<title */
} DRM_EVENT_TYPE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_PERMISSION_ANY = 0,			   /**<all permission*/
	DRM_PERMISSION_PLAY = 1,			   /**<play permission*/
	DRM_PERMISSION_DISPLAY = 2,			   /**<display permission*/
	DRM_PERMISSION_EXECUTE = 4,			   /**<execute permission */
	DRM_PERMISSION_PRINT = 8,			   /**<print permission */
	DRM_PERMISSION_EXPORT_COPY = 16,			   /**<export copy permission*/
	DRM_PERMISSION_EXPORT_MOVE = 32			   /**<export move permission */
} DRM_PERMISSION_TYPE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_RIGHT_VALID,		/**<rights is valid */
	DRM_RIGHT_FUTUREUSE,		/**<rights is suspended */
	DRM_RIGHT_EXPIRED,		/**<rights is expired */
	DRM_RIGHT_NORIGHTS,		/**<rights is not exist */
} DRM_STATUS_RIGHTS;

/**
* Enumeration Template
*/
typedef enum {
	DRM_UNLIMITED = 0,		/**<unlimited */
	DRM_COUNT = 1,		/**<count */
	DRM_DATETIME = 2,		/**<datetime */
	DRM_INTERVAL = 4,		/**<interval */
	DRM_TIMED_COUNT = 8,		/**<timed count */
	DRM_ACCUMULATED = 16,		/**<accumulated */
	DRM_INDIVIDUAL = 32,		/**<individual */
	DRM_SYSTEM = 64		/**<system */
} DRM_CONSTRAINT_TYPE;

/**
* Enumeration Template
*/
enum {
	DRM_RIGHTS_CONSUME = 0,		      /**<consume handle */
	DRM_RIGHTS_TRAVERSE = 1,		      /**<traverse handle */
	DRM_RIGHTS_CONSUME_FL = 2		      /**<FL consume handle */
};

/**
* Enumeration Template
*/
typedef enum {
	DRM_METHOD_UNDEFINED = -1,    /**<error */
	DRM_METHOD_FL = 0,		     /**<FL */
	DRM_METHOD_CD,				/**<CD */
	DRM_METHOD_SSD,		      	/**<FL-SD */
	DRM_METHOD_SD 				/**<SD */
} DRM_METHOD;

/**
* Enumeration Template
*/
typedef enum {
	DRM_CONTENTS_INDEX_PREIVEW,			    /**<preview */
	DRM_CONTENTS_INDEX_ALBUMJACKET,			/**<album jacket */
	DRM_CONTENTS_INDEX_LYRICS			    /**<lyrics */
} DRM_CONTENTS_INDEX_TYPE;

/**
* Enumeration Template
*/
typedef enum {
	DRM_UDTA_TITLE,		   			/**<title */
	DRM_UDTA_DESCRIPTION,		   	/**<description */
	DRM_UDTA_COPYRIGHT,		   		/**<title */
	DRM_UDTA_AUTHOR,		   		/**<author */
	DRM_UDTA_ICON_URI,		   		/**<icon URI */
	DRM_UDTA_INFO_URL,		   		/**<info URL */
	DRM_UDTA_PERFORMER,		  		/**<performer */
	DRM_UDTA_GENRE,		   			/**<genre */
	DRM_UDTA_COVERURI,		  		/**<cover URI */
	DRM_UDTA_LYRICSURI,			   	/**<lyrics URI */
	DRM_UDTA_RATING,			   	/**<rating */
	DRM_UDTA_CLASSIFICATION,		/**<classification */
	DRM_UDTA_KEYWORD,			   	/**<keyword */
	DRM_UDTA_LOCATIONINFO,		   	/**<location info */
	DRM_UDTA_ALBUM,				   	/**<album */
	DRM_UDTA_RECODINGYEAR		   	/**<recoding year */
} DRM_METADATABOX_TYPE;

/**
*  Type Definition Template
*/
typedef struct {
	drm_time_t startTime;		  /**<drm_time_t*/
	drm_time_t endTime;		  /**<drm_time_t*/
} drm_datetime_t;

/**
*  Type Definition Template
*/
typedef struct {
	int time;		      /**<int*/
	unsigned int count;	      /**<unsigned int*/
} drm_timedcount_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_CONSTRAINT_TYPE orgConstraints;   /**<DRM_CONSTRAINT_TYPE*/
	unsigned int orgCount;		      /**<unsigned int*/
	drm_datetime_t orgDateTime;	      /**<drm_datetime_t*/
	drm_time_t orgInterval;		      /**<drm_time_t*/
	drm_timedcount_t orgTimedCount;	      /**<drm_timed_count*/
	int orgAccumulated;		      /**<int*/
	DRM_CONSTRAINT_TYPE curConstraints;   /**<DRM_CONSTRAINT_TYPE*/
	unsigned int curCount;		      /**<int*/
	drm_datetime_t curDateTime;	      /**<drm_datetime_t*/
	drm_time_t curInterval;		      /**<drm_time_t*/
	drm_timedcount_t curTimedCount;	      /**<drm_timedcount_t*/
	int curAccumulated;		      /**<int*/
} drm_constraint_info_t;

/**
*  Type Definition Template
*/
typedef struct {
	drm_constraint_info_t constraint;     /**<drm_constraint_info_t*/
	DRM_PERMISSION_TYPE permissionType;   /**<DRM_PERMISSION_TYPE*/
	DRM_STATUS_RIGHTS status;	      /**<DRM_STATUS_RIGHTS*/
} drm_permission_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned char name[DRM_MAX_DOMAIN_ID_SIZE + 1];	       /**<unsigned char []*/
	unsigned int generation;			     /**<unsigned int*/
} drm_domain_id_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_RIGHTS_VERSION version;				      /**<DRM_RIGHTS_VERSION*/
	unsigned char roID[DRM_MAX_ROID_LEN];			      /**<unsigned char []*/
	unsigned char riID[DRM_MAX_RIID_LEN];			      /**<unsigned char []*/
	unsigned char riUrl[DRM_MAX_RIURL_LEN];			      /**<unsigned char []*/
	unsigned char roAlias[DRM_MAX_ROALIAS_LEN];		      /**<unsigned char []*/
	DRM_BOOL bIsDomainRO;					      /**<DRM_BOOL*/
	drm_domain_id_t domainID;				      /**<drm_domain_id_t*/
	unsigned char cid[DRM_MAX_CID_LEN + 1];				 /**<unsigned char []*/
	DRM_BOOL bIsParentRO;					      /**<DRM_BOOL*/
	DRM_BOOL bIsChildRO;					      /**<DRM_BOOL*/
	unsigned char parentID[DRM_MAX_PID_LEN];		      /**<unsigned char []*/
	unsigned int permCount;					      /**<unsigned int*/
	drm_permission_t permission[DRM_MAX_PERMISSION_COUNT];	      /**<drm_permission_t*/
} drm_rights_info_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_RIGHTS_VERSION version;		       /**<DRM_RIGHTS_VERSION*/
	DRM_STATUS_RIGHTS rightStatus;		       /**<DRM_STATUS_RIGHTS*/
	DRM_BOOL bIsDomainRO;			       /**<DRM_BOOL*/
	unsigned char riID[DRM_MAX_RIID_LEN];	       /**<unsigned char*/
	drm_domain_id_t domainID;		       /**<drm_domain_id_t*/
	drm_permission_t bestPermission;	       /**<drm_permission_t*/
} drm_best_rights_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned int size;		   /**<unsigned int*/
	unsigned int createTime;	   /**<unsigned int*/
	unsigned int modifyTime;	   /**<unsigned int*/
	unsigned int attribute;		   /**<unsigned int*/
} drm_file_attribute_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned char cek[DRM_CEK_SIZE];		  /**<unsinged char []*/
	char digest[DRM_DIGEST_SIZE];			  /**<char [] */
	DRM_BOOL bIsGroupKey;				  /**<DRM_BOOL */
} drm_keyinfo_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned char type;	     /**<unsigned char*/
	unsigned int cur;	     /**<unsigned int*/
	void *data;		     /**<void **/
} drm_rights_handle_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_RIGHTS_VERSION version;	/**<DRM_RIGHTS_VERSION*/
	DRM_METHOD method;		/**<DRM_METHOD*/
} drm_dcf_info_t;

typedef struct {
	int contentIdx;												/**<int*/
	char contentID[DRM_MAX_CID_LEN + 1];					/**<char []*/
	char contentType[DRM_MAX_TYPE_LEN + 1];					/**<char []*/
} drm_content_info_t;

/**
*  Type Definition Template
*/
typedef struct {
	char contentName[DRM_MAX_CONTENT_NAME_LEN];				     /**<char []*/
	char contentDescription[DRM_MAX_CONTENT_DESCRIPTION_LEN];		     /**<char []*/
	char contentVendor[DRM_MAX_VENDOR_LEN];					     /**<char []*/
	char iconUrl[DRM_MAX_ICON_URI_LEN];					     /**<char []*/
} drm_dcf_v1_header_info_t;

/**
*  Type Definition Template
*/
typedef struct {
	char title[DRM_MAX_TITLE_LEN];					       /**<char []*/
	char description[DRM_MAX_CONTENT_DESCRIPTION_LEN];		       /**<char []*/
	char copyright[DRM_MAX_COPYRIGHT_LEN];				       /**<char []*/
	char author[DRM_MAX_AUTHOR_LEN];				       /**<char []*/
	char iconUrl[DRM_MAX_ICON_URI_LEN];				       /**<char []*/
	char infoUrl[DRM_MAX_INFO_URL_LEN];				       /**<char []*/
} drm_dcf_v2_header_info_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_RIGHTS_VERSION version;	/**<DRM_RIGHTS_VERSION*/
	drm_dcf_desc_t desc;		/**<drm_dcf_desc_t*/
	union {
		drm_dcf_v1_header_info_t headerV1;					/**<drm_dcf_v1_header_info_t*/
		drm_dcf_v2_header_info_t headerV2;					/**<drm_dcf_v2_haeder_info_t*/
	} headerUnion;	     /**<headerUnion*/
} drm_dcf_header_t;

/**
*  Type Definition Template
*/
typedef struct {
	char filePath[DRM_MAX_FILEPATH_LEN];		       /**<char []*/
} drm_file_path_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned int totalCount;	   /**<unsigned int*/
	drm_file_path_t *filePath;	   /**<drm_file_path_t*/
} drm_file_path_list_t;

/**
*  Type Definition Template
*/
typedef struct {
	char cid[DRM_MAX_CID_LEN + 1];			 /**<char []*/
} drm_cid_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned int TotalCidCount;	      /**<Total count of CIDs present*/
	drm_cid_t *cid_list;	     /**<drm_cid_t*/
} drm_cid_list_t;

/**
*  Type Definition Template
*/
typedef struct {
	int runAlarmID;
	unsigned long expiryTime;
} drm_run_alarm_data_t;

/**
*  Type Definition Template
*/
typedef struct {
	char filePath[DRM_MAX_FILEPATH_LEN + 1];
	unsigned long expirytime;
	DRM_SETAS_CATEGORY settingCategory;
	DRM_DB_EXPIRY_TYPE expiryType;
	int expiryAlarmID;
} drm_expiry_alarm_data_t;

/**
*  Type Definition Template
*/
typedef struct {
	DRM_ALARM_TYPE alarmType;
	union {
		drm_run_alarm_data_t runAlarmInfo;
		drm_expiry_alarm_data_t expiryAlarmInfo;
	} AlarmTypeUnion;
} drm_alarm_data_t;

/**
*  Type Definition Template
*/
typedef struct {
	unsigned int count;		   /**<unsigned int*/
	drm_time_t time;		   /**<drm_time_t*/
} drm_param_check_expire_t;

/**
* The prototye of drm alarm handler.
* param [in] 	alarm_id alarm id expired
*/
typedef int (*drm_alarm_cb_t) (int alarm_id);

/**
*  Type Definition Template
*/
typedef int (*drm_odf_start_download_t) (void *appSessionData);

/**
*  Type Definition Template
*/
typedef int (*drm_odf_progress_download_t) (const void *pData,
						    unsigned int DataLen,
						    void *appSessionData);

/**
*  Type Definition Template
*/
typedef int (*drm_odf_finish_download_t) (void *appSessionData);

/**
*  Type Definition Template
*/
/*This enum is defined to send the type of error while notifying to application*/

typedef drm_odf_start_download_t drm_odf_start_download_cb;
/**
*  Type Definition Template
*/
typedef drm_odf_progress_download_t drm_odf_progress_download_cb;
/**
*  Type Definition Template
*/
typedef drm_odf_finish_download_t drm_odf_finish_download_cb;

/**
*  Type Definition Template
*/

typedef struct {
	drm_odf_start_download_cb start_download_cb;   /**<drm_odf_start_download_cb*/
	drm_odf_progress_download_cb progress_download_cb;
						       /**<drm_odf_progress_download_cb*/
	drm_odf_finish_download_cb finish_download_cb; /**<drm_odf_finish_download_cb*/
} drm_odf_download_cb_t;

/**
*  Type Definition Template
*/
typedef struct {
	int profileID;							 /**<int*/
	int is_progressive_download;					 /**<int*/
	char pProxyAddress[DRM_MAX_IP_ADDR + 1];			 /**<char []**/
	drm_odf_download_cb_t odf_download_cb;				 /**odf_download_cb**/
	void *pData;							 /**<void */
} drm_appsession_datatype_t;

/**
*  Type Definition Template for PD
*/
typedef enum {
	DRM_PARSING_WAIT,
	DRM_PARSING_PARSE,
	DRM_PARSING_UNLOCK,
	DRM_PARSING_NEED_KEY,
	DRM_PARSING_DECRYPT,
	DRM_PARSING_SKIP,
	DRM_PARSING_EOF
} DRM_PARSING_STATUS;

/**
*  Type Definition Template for PD
*/
typedef struct {
	DRM_PARSING_STATUS status;
	int nIndex;
	char
	 contentType[DRM_MAX_MIME_LEN + 1];
	unsigned int nFullPlaintextSize;
	unsigned int nCurrDownloadPlaintextSize;
} drm_pd_parsing_status_t;

typedef enum {
	DRM_PATH_INDEX_MULTIPART,
	DRM_PATH_INDEX_EMBEDDED,
	DRM_PATH_INDEX_MAX
} DRM_PATH_INDEX;

#define DRM_APP_ID_LAUNCHER 10

#define DIVXDRM_VERSION 2

typedef enum {
	CONSTRAINT_TYPE_RENTAL = 0,
	CONSTRAINT_TYPE_RENTAL_UNLIMITED,
	CONSTRAINT_TYPE_PURCHASE,
	CONSTRAINT_TYPE_BASE,
	CONSTRAINT_TYPE_EXPIRED,
	CONSTRAINT_TYPE_NOT_AUTHORIZED,
	CONSTRAINT_TYPE_INVALID_DIVXDRM_VERSION,
	CONSTRAINT_TYPE_UNKNOWN_TYPE,
	CONSTRAINT_TYPE_GENERAL_ERROR
} drmConstraint_t;

typedef struct {
	drmConstraint_t type;
	int totalCount;
	int useCount;
} drmContentInfo_t;

typedef struct {
	unsigned char *havi;
	unsigned char *drmContext;
	int DIVX_COMMIT_FLAG;
} divxdrm_t;

typedef struct {
	/* drm version number */
	int version;
	int drm_size;
	/* encrpyted drm info */
} drm_strd_drm_info_s;

/**
*  Type Definition Template
*/
typedef enum WMDRM_Lic_Category {
	WMDRM_LIC_STATE_NORIGHT = 0,			 	/**<No rights to perform this action */
	WMDRM_LIC_STATE_UNLIM,		   				/**<Unlimited rights to perform this action */
	WMDRM_LIC_STATE_COUNT,		   				/**<Action may only be performed a certain number of times */
	WMDRM_LIC_STATE_FROM,		   				/**<Action cannot be performed until a specific date */
	WMDRM_LIC_STATE_UNTIL,		   				/**<Action cannot be performed after a certain date */
	WMDRM_LIC_STATE_FROM_UNTIL,			 		/**<Action can only be performed within a specific range of dates */
	WMDRM_LIC_STATE_COUNT_FROM,			 		/**<Action can only be performed a certain number of times, starting from a specific date */
	WMDRM_LIC_STATE_COUNT_UNTIL,			 	/**<Action can be performed a certain number of times until a specific date */
	WMDRM_LIC_STATE_COUNT_FROM_UNTIL,			/**<Action can only be performed a certain number of times, and only is a specific range of dates */
	WMDRM_LIC_STATE_EXPIRATION_AFTER_FIRSTUSE,	/**<License restrictions don't occur until after the first use */
	WMDRM_LIC_STATE_FORCE_SYNC		      		/**<Force to synchronize license */
} WMDRM_LIC_CATEGORY;

typedef struct DRM_WM_RightInfo {
	WMDRM_LIC_CATEGORY type;
	int totalCount;
	int remainingCount;
	struct tm start_time;
	struct tm end_time;
} drm_wm_RightInfo_t;

typedef struct DRM_WM_CONTENT_RIGHT_INFO {
	drm_wm_RightInfo_t *stPlayBack;
	drm_wm_RightInfo_t *stCollaborativePlay;
	drm_wm_RightInfo_t *stCopyCD;
} drm_wm_content_right_info;

/* debug setting */
#define MAX_DEP				10
#define MAX_DEP_LEN			MAX_DEP*2
#define MAX_DEBUG_LINE		1024

extern char gDebugStrDep[MAX_DEP_LEN + 1];
extern int gDebugDepth;
extern int gDebugfuncFilter;

typedef struct {
	/* DRM_APP_CONTEXT sepcific Data*/
	void *pAppContext;

	/* DRM_DECRYPT_CONTEXT specific data */
	void *pDecryptContext;

	/* Opaque Buffer specific data */
	void *opaque_buffer;

	/* DRM_ASFVERIFYCONTEXT specific data */
	void *pToolContext;

	/* DRM PlayReady Revocation Buffer */
	unsigned char *RevocationBuffer;

	/* License permission type */
	DRM_PERMISSION_TYPE PermissionType;

	/* Response Data */
	drm_pr_response_data *PRespData;

} DRM_PLAYREADY_HANDLE;

#ifdef __cplusplus
}
#endif
#endif
